@@ -39,6 +39,12 @@
 /* our global datas */
 extern struct HomeBank *GLOBALS;
 
+enum {
+	HID_VALID,
+	HID_REMIND,
+	MAX_HID
+};
+
 struct defarchive_data
 {
 	GList	*tmp_list;
@@ -54,6 +60,7 @@ struct defarchive_data
 	GtkWidget	*ST_amount, *BT_amount;
 	GtkWidget	*notebook;
 	GtkWidget	*CM_valid;
+	GtkWidget	*CM_remind;
 	GtkWidget	*GR_cheque;
 	GtkWidget	*CM_cheque;
 
@@ -73,35 +80,21 @@ struct defarchive_data
 	GtkWidget	*BT_ren;
 	GtkWidget	*BT_rem;
 
-	//gulong		handler_id[MAX_FIELD];
+	gulong		handler_id[MAX_HID];
 
 };
 
-void defarchive_add(GtkWidget *widget, gpointer user_data);
-void defarchive_remove(GtkWidget *widget, gpointer user_data);
-void defarchive_update(GtkWidget *widget, gpointer user_data);
-void defarchive_set(GtkWidget *widget, gpointer user_data);
-void defarchive_get(GtkWidget *widget, gpointer user_data);
-void defarchive_toggleamount(GtkWidget *widget, gpointer user_data);
-void defarchive_paymode(GtkWidget *widget, gpointer user_data);
-void defarchive_automatic(GtkWidget *widget, gpointer user_data);
-gboolean defarchive_cleanup(struct defarchive_data *data, gint result);
-void defarchive_setup(struct defarchive_data *data);
-void defarchive_dispose(struct defarchive_data *data);
-void defarchive_getlast(struct defarchive_data *data);
-void defarchive_rename(GtkWidget *widget, gpointer user_data);
-
-GtkWidget *defarchive_list_new(void);
 
 
 gchar *CYA_UNIT[] = { N_("Day"), N_("Week"), N_("Month"), N_("Year"), NULL };
 
 
+static GtkWidget *defarchive_list_new(void);
 
 /*
 ** add an empty new account to our temp GList and treeview
 */
-void defarchive_add(GtkWidget *widget, gpointer user_data)
+static void defarchive_add(GtkWidget *widget, gpointer user_data)
 {
 struct defarchive_data *data;
 GtkTreeModel *model;
@@ -115,7 +108,7 @@ Archive *item;
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_arc));
 
 	item = da_archive_malloc();
-	item->wording = g_strdup(_("(new archive)"));
+	item->wording = g_strdup_printf(_("(archive %d)"), g_list_length(GLOBALS->arc_list) + 1);
 
 	GLOBALS->arc_list = g_list_append(GLOBALS->arc_list, item);
 
@@ -133,7 +126,7 @@ Archive *item;
 /*
 ** remove the selected account to our treeview and temp GList
 */
-void defarchive_remove(GtkWidget *widget, gpointer user_data)
+static void defarchive_remove(GtkWidget *widget, gpointer user_data)
 {
 struct defarchive_data *data;
 GtkTreeSelection *selection;
@@ -158,82 +151,52 @@ Archive *item;
 	}
 }
 
+
 /*
-** update the widgets status and contents from action/selection value
+** update the archive name everytime it changes
 */
-void defarchive_update(GtkWidget *widget, gpointer user_data)
+static void defarchive_rename(GtkWidget *widget, gpointer user_data)
 {
 struct defarchive_data *data;
+GtkTreeSelection *selection;
 GtkTreeModel		 *model;
 GtkTreeIter			 iter;
-gboolean selected, sensitive;
-Archive *arcitem;
+gchar *txt;
+Archive *item;
 
-	DB( g_printf("\n****(defarchive) update\n") );
+	DB( g_print("(defarchive) rename\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-	//window = gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW);
-	//DB( g_printf("(defarchive) widget=%08lx, window=%08lx, inst_data=%08lx\n", treeview, window, data) );
 
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_arc));
 	//if true there is a selected node
-	selected = gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_arc)), &model, &iter);
-
-	DB( g_printf(" selected = %d\n", selected) );
-
-	sensitive = (selected == TRUE) ? TRUE : FALSE;
-	gtk_widget_set_sensitive(data->PO_pay, sensitive);
-	gtk_widget_set_sensitive(data->ST_word, sensitive);
-	gtk_widget_set_sensitive(data->ST_amount, sensitive);
-	gtk_widget_set_sensitive(data->BT_amount, sensitive);
-	//gtk_widget_set_sensitive(data->CY_amount, sensitive);
-	gtk_widget_set_sensitive(data->CM_valid, sensitive);
-	gtk_widget_set_sensitive(data->CM_cheque, sensitive);
-
-	gtk_widget_set_sensitive(data->NU_mode, sensitive);
-	gtk_widget_set_sensitive(data->PO_grp, sensitive);
-	gtk_widget_set_sensitive(data->PO_acc, sensitive);
-	gtk_widget_set_sensitive(data->PO_accto, sensitive);
-
-	gtk_widget_set_sensitive(data->CM_auto, sensitive);
-
-	//sensitive = (data->action == 0) ? TRUE : FALSE;
-	//gtk_widget_set_sensitive(data->LV_arc, sensitive);
-	//gtk_widget_set_sensitive(data->BT_new, sensitive);
-
-	//sensitive = (selected == TRUE && data->action == 0) ? TRUE : FALSE;
-	gtk_widget_set_sensitive(data->BT_rem, sensitive);
-
-	if(selected)
+	if (gtk_tree_selection_get_selected(selection, &model, &iter))
 	{
-		gtk_tree_model_get(model, &iter, LST_DEFARC_DATAS, &arcitem, -1);
-
-		if(data->lastarcitem != NULL && arcitem != data->lastarcitem)
-		{
-			DB( g_print(" -> should do a get for last selected (%s)\n", data->lastarcitem->wording) );
-			defarchive_getlast(data);
-		}
-		data->lastarcitem = arcitem;
-
-
-		defarchive_set(widget, NULL);
-		
-	}
-	else
-	{
-		data->lastarcitem = NULL;
+		gtk_tree_model_get(model, &iter, LST_DEFARC_DATAS, &item, -1);
 	
+		DB( g_print(" -> %s\n", item->wording) );
+
+		txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_word));
+		// ignore if entry is empty
+		if (txt && *txt)
+		{
+			g_free(item->wording);
+			item->wording = g_strdup(txt);
+		}
+
+		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_arc));
+
 	}
 
-	defarchive_paymode(widget,NULL);
-	defarchive_automatic(widget,NULL);
-
-
 }
 
+
+
+
 /*
 ** set widgets contents from the selected account
 */
-void defarchive_set(GtkWidget *widget, gpointer user_data)
+static void defarchive_set(GtkWidget *widget, gpointer user_data)
 {
 struct defarchive_data *data;
 GtkTreeSelection *selection;
@@ -257,9 +220,14 @@ Archive *item;
 
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), item->amount);
 
-
+		g_signal_handler_block(data->CM_valid, data->handler_id[HID_VALID]);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_valid), (item->flags & OF_VALID) ? 1 : 0);
-
+		g_signal_handler_unblock(data->CM_valid, data->handler_id[HID_VALID]);
+		
+		g_signal_handler_block(data->CM_remind, data->handler_id[HID_REMIND]);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_remind), (item->flags & OF_REMIND) ? 1 : 0);
+		g_signal_handler_unblock(data->CM_remind, data->handler_id[HID_REMIND]);
+	
 		gtk_combo_box_set_active(GTK_COMBO_BOX(data->NU_mode), item->paymode);
 
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_cheque), (item->flags & OF_CHEQ2) ? 1 : 0);
@@ -294,7 +262,7 @@ Archive *item;
 /*
 ** get widgets contents to the selected account
 */
-void defarchive_getlast(struct defarchive_data *data)
+static void defarchive_getlast(struct defarchive_data *data)
 {
 gchar *txt;
 gboolean bool;
@@ -335,6 +303,9 @@ Archive *item;
 		bool = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_valid));
 		if(bool) item->flags |= OF_VALID;
 
+		bool = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_remind));
+		if(bool == 1) item->flags |= OF_REMIND;
+
 		item->paymode		= gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode));
 		item->category		= ui_cat_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_grp));
 		item->payee			= ui_pay_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_pay));
@@ -356,95 +327,15 @@ Archive *item;
 
 		item->limit   = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_limit));
 
-		
-		/*
-		todo
-		
-		switch( field )
-		{
-			case FIELD_PAYMODE:
-				defarchive_paymode(widget, NULL);
-				break;
-
-			case FIELD_AUTO:
-			case FIELD_LIMIT:
-				defarchive_automatic(widget, NULL);
-				break;
-
-		}*/
-
 		data->change++;
 	}
 }
 
 
-/*
-** update the archive name everytime it changes
-*/
-void defarchive_rename(GtkWidget *widget, gpointer user_data)
-{
-struct defarchive_data *data;
-GtkTreeSelection *selection;
-GtkTreeModel		 *model;
-GtkTreeIter			 iter;
-gchar *txt;
-Archive *item;
-
-	DB( g_print("(defarchive) rename\n") );
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
-	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_arc));
-	//if true there is a selected node
-	if (gtk_tree_selection_get_selected(selection, &model, &iter))
-	{
-		gtk_tree_model_get(model, &iter, LST_DEFARC_DATAS, &item, -1);
-	
-		DB( g_print(" -> %s\n", item->wording) );
-
-		txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_word));
-		// ignore if entry is empty
-		if (txt && *txt)
-		{
-			g_free(item->wording);
-			item->wording = g_strdup(txt);
-		}
-
-		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_arc));
-
-	}
-
-}
-
 /*
 **
 */
-void defarchive_toggleamount(GtkWidget *widget, gpointer user_data)
-{
-struct defarchive_data *data;
-gdouble value;
-
-	DB( g_printf("(defarchive) toggleamount\n") );
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
-	value = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
-	value *= -1;
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), value);
-
-
-	/*
-	value = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
-	type = gtk_widget_get_sensitive(data->CY_amount);
-
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), value * type);
-	*/
-}
-
-/*
-**
-*/
-void defarchive_paymode(GtkWidget *widget, gpointer user_data)
+static void defarchive_paymode(GtkWidget *widget, gpointer user_data)
 {
 struct defarchive_data *data;
 gint payment;
@@ -457,9 +348,9 @@ gint page;
 	payment = gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode));
 	page = 0;
 
-	if(payment == PAYMODE_CHEQUE)
+	if(payment == PAYMODE_CHECK)
 		page = 1;
-	if(payment == PAYMODE_PERSTRANSFER)
+	if(payment == PAYMODE_INTXFER)
 		page = 2;
 
 	DB( g_printf(" payment: %d, page: %d\n", payment, page) );
@@ -470,7 +361,7 @@ gint page;
 /*
 **
 */
-void defarchive_automatic(GtkWidget *widget, gpointer user_data)
+static void defarchive_automatic(GtkWidget *widget, gpointer user_data)
 {
 struct defarchive_data *data;
 gboolean sensitive;
@@ -492,6 +383,141 @@ gboolean sensitive;
 
 }
 
+
+/*
+** update the widgets status and contents from action/selection value
+*/
+static void defarchive_update(GtkWidget *widget, gpointer user_data)
+{
+struct defarchive_data *data;
+GtkTreeModel		 *model;
+GtkTreeIter			 iter;
+gboolean selected, sensitive;
+Archive *arcitem;
+
+
+	DB( g_printf("(defarchive) update\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+	//window = gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW);
+	//DB( g_printf("(defarchive) widget=%08lx, window=%08lx, inst_data=%08lx\n", treeview, window, data) );
+
+	//if true there is a selected node
+	selected = gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_arc)), &model, &iter);
+
+	DB( g_printf(" selected = %d\n", selected) );
+
+	sensitive = (selected == TRUE) ? TRUE : FALSE;
+	gtk_widget_set_sensitive(data->PO_pay, sensitive);
+	gtk_widget_set_sensitive(data->ST_word, sensitive);
+	gtk_widget_set_sensitive(data->ST_amount, sensitive);
+	gtk_widget_set_sensitive(data->BT_amount, sensitive);
+
+	gtk_widget_set_sensitive(data->CM_valid, sensitive);
+	gtk_widget_set_sensitive(data->CM_remind, sensitive);
+	
+	gtk_widget_set_sensitive(data->CM_cheque, sensitive);
+
+	gtk_widget_set_sensitive(data->NU_mode, sensitive);
+	gtk_widget_set_sensitive(data->PO_grp, sensitive);
+	gtk_widget_set_sensitive(data->PO_acc, sensitive);
+	gtk_widget_set_sensitive(data->PO_accto, sensitive);
+
+	gtk_widget_set_sensitive(data->CM_auto, sensitive);
+
+	gtk_widget_set_sensitive(data->BT_rem, sensitive);
+
+
+
+	if(selected)
+	{
+		gtk_tree_model_get(model, &iter, LST_DEFARC_DATAS, &arcitem, -1);
+
+		if(data->lastarcitem != NULL && arcitem != data->lastarcitem)
+		{
+			DB( g_print(" -> should do a get for last selected (%s)\n", data->lastarcitem->wording) );
+			defarchive_getlast(data);
+		}
+		data->lastarcitem = arcitem;
+
+
+		defarchive_set(widget, NULL);
+		
+	}
+	else
+	{
+		data->lastarcitem = NULL;
+	
+	}
+
+	defarchive_automatic(widget, NULL);
+	defarchive_paymode(widget,NULL);
+
+
+}
+
+static void defarchive_togglestatus(GtkWidget *widget, gpointer user_data)
+{
+struct defarchive_data *data;
+
+	DB( g_printf("(defarchive) togglestatus\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	//valid & remind are exclusive
+	switch( GPOINTER_TO_INT(user_data) )
+	{
+		case HID_VALID:
+			if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_valid)) )
+			{
+				g_signal_handler_block(data->CM_remind, data->handler_id[HID_REMIND]);
+				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_remind), FALSE);
+				g_signal_handler_unblock(data->CM_remind, data->handler_id[HID_REMIND]);
+			}
+			break;
+		
+		case HID_REMIND:
+			if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_remind)) )
+			{
+				g_signal_handler_block(data->CM_valid, data->handler_id[HID_VALID]);
+				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_valid), FALSE);
+				g_signal_handler_unblock(data->CM_valid, data->handler_id[HID_VALID]);
+			}
+	}
+
+
+
+
+}
+
+
+
+/*
+**
+*/
+static void defarchive_toggleamount(GtkWidget *widget, gpointer user_data)
+{
+struct defarchive_data *data;
+gdouble value;
+
+	DB( g_printf("(defarchive) toggleamount\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	value = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
+	value *= -1;
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), value);
+
+
+	/*
+	value = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
+	type = gtk_widget_get_sensitive(data->CY_amount);
+
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), value * type);
+	*/
+}
+
+
 /*
 **
 */
@@ -503,7 +529,7 @@ static void defarchive_selection(GtkTreeSelection *treeselection, gpointer user_
 /*
 **
 */
-gboolean defarchive_cleanup(struct defarchive_data *data, gint result)
+static gboolean defarchive_cleanup(struct defarchive_data *data, gint result)
 {
 gboolean doupdate = FALSE;
 
@@ -516,6 +542,8 @@ gboolean doupdate = FALSE;
 		defarchive_getlast(data);
 	}
 
+	GLOBALS->arc_list = da_archive_sort(GLOBALS->arc_list);
+	
 	GLOBALS->change += data->change;
 
 	return doupdate;
@@ -524,7 +552,7 @@ gboolean doupdate = FALSE;
 /*
 **
 */
-void defarchive_setup(struct defarchive_data *data)
+static void defarchive_setup(struct defarchive_data *data)
 {
 GtkTreeModel *model;
 GtkTreeIter  iter;
@@ -542,7 +570,8 @@ gint i;
 
 	//insert all glist item into treeview
 	model  = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_arc));
-	i=0; list = g_list_first(GLOBALS->arc_list);
+	i=0;
+	list = g_list_first(GLOBALS->arc_list);
 	while (list != NULL)
 	{
 	Archive *item = list->data;
@@ -589,7 +618,8 @@ gint row;
 
 	gtk_dialog_set_has_separator(GTK_DIALOG (window), FALSE);
 	
-	homebank_window_set_icon_from_file(GTK_WINDOW (window), "archive.svg");
+	//homebank_window_set_icon_from_file(GTK_WINDOW (window), "archive.svg");
+	gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_ARCHIVE);
 
 	//store our window private data
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)&data);
@@ -686,6 +716,11 @@ gint row;
 	data.CM_valid = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("_Remind"));
+	data.CM_remind = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+
 	//**
 
 	row++;
@@ -805,13 +840,7 @@ gint row;
 	g_signal_connect (G_OBJECT (data.BT_new), "clicked", G_CALLBACK (defarchive_add), NULL);
 	g_signal_connect (G_OBJECT (data.BT_rem), "clicked", G_CALLBACK (defarchive_remove), NULL);
 
-	// modify events
-	//data.handler_id[FIELD_PAYEE] = g_signal_connect (data.PO_pay, "changed", G_CALLBACK (defarchive_get), GINT_TO_POINTER(FIELD_PAYEE));
-
 	g_signal_connect (G_OBJECT (data.ST_word), "changed", G_CALLBACK (defarchive_rename), NULL);
-	//g_signal_connect (G_OBJECT (data.ST_word), "focus-out-event", G_CALLBACK (defarchive_focus_out), GINT_TO_POINTER(FIELD_WORDING));
-	//data.handler_id[FIELD_AMOUNT] = g_signal_connect (data.ST_amount, "value-changed", G_CALLBACK (defarchive_get), GINT_TO_POINTER(FIELD_AMOUNT));
-	//data.handler_id[FIELD_VALID] = g_signal_connect (data.CM_valid, "toggled", G_CALLBACK (defarchive_get), GINT_TO_POINTER(FIELD_VALID));
 
 	 g_signal_connect (data.NU_mode, "changed", G_CALLBACK (defarchive_paymode), NULL);
 	//data.handler_id[FIELD_CHEQUE] = g_signal_connect (data.CM_cheque, "toggled", G_CALLBACK (defarchive_get), GINT_TO_POINTER(FIELD_CHEQUE));
@@ -819,6 +848,9 @@ gint row;
 	//data.handler_id[FIELD_ACCOUNT] = g_signal_connect (data.PO_acc, "changed", G_CALLBACK (defarchive_get), GINT_TO_POINTER(FIELD_ACCOUNT));
 	//data.handler_id[FIELD_TOACCOUNT] = g_signal_connect (data.PO_accto, "changed", G_CALLBACK (defarchive_get), GINT_TO_POINTER(FIELD_TOACCOUNT));
 
+	data.handler_id[HID_VALID]  = g_signal_connect (data.CM_valid , "toggled", G_CALLBACK (defarchive_togglestatus), GINT_TO_POINTER(HID_VALID));
+	data.handler_id[HID_REMIND] = g_signal_connect (data.CM_remind, "toggled", G_CALLBACK (defarchive_togglestatus), GINT_TO_POINTER(HID_REMIND));
+
 	g_signal_connect (data.CM_auto, "toggled", G_CALLBACK (defarchive_automatic), NULL);
 	//data.handler_id[FIELD_EVERY] = g_signal_connect (data.NB_every, "value-changed", G_CALLBACK (defarchive_get), GINT_TO_POINTER(FIELD_EVERY));
 	//data.handler_id[FIELD_UNIT] = g_signal_connect (data.CY_unit, "changed", G_CALLBACK (defarchive_get), GINT_TO_POINTER(FIELD_UNIT));
@@ -855,24 +887,37 @@ gint row;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-
 /*
 **
+** The function should return:
+** a negative integer if the first value comes before the second,
+** 0 if they are equal,
+** or a positive integer if the first value comes after the second.
 */
-gint defarchive_list_sort(Archive *a, Archive *b)
+static gint defarchive_list_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
-gint result;
+gint result = 0;
+Archive *entry1, *entry2;
+gchar *name1, *name2;
 
-//	result = a->category - b->category;
-//	if(result == 0)
+	gtk_tree_model_get(model, a, LST_DEFARC_DATAS, &entry1, -1);
+	gtk_tree_model_get(model, b, LST_DEFARC_DATAS, &entry2, -1);
 
-	result = g_utf8_collate(a->wording, b->wording);
-
-	return result;
+	name1 = entry1->wording;
+	name2 = entry2->wording;
+    if (name1 == NULL || name2 == NULL)
+    {
+      result = (name1 == NULL) ? -1 : 1;
+    }
+    else
+    {
+      result = g_utf8_collate(name1,name2);
+    }
+	
+    return result;
 }
 
 
-
 /*
 **
 */
@@ -916,7 +961,7 @@ gchar *name;
 /*
 **
 */
-GtkWidget *defarchive_list_new(void)
+static GtkWidget *defarchive_list_new(void)
 {
 GtkListStore *store;
 GtkWidget *view;
@@ -932,8 +977,7 @@ GtkTreeViewColumn  *column;
 		);
 
 	//sortable
-	//gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFPAY_DATAS, sort_iter_compare_func, GINT_TO_POINTER(LST_DEFPAY_DATAS), NULL);
-	//gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), LST_DEFPAY_DATAS, GTK_SORT_ASCENDING);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_DATAS, defarchive_list_compare_func, GINT_TO_POINTER(LST_DEFARC_DATAS), NULL);
 
 
 	//treeview
