@@ -219,7 +219,7 @@ GIOChannel *io;
 
 	DB( g_printf("(defbudget) load csv - data %x\n", data) );
 
-	if( homebank_csv_file_chooser(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_OPEN, &filename) == TRUE )
+	if( homebank_csv_file_chooser(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_OPEN, &filename, NULL) == TRUE )
 	{
 		DB( g_print(" + filename is %s\n", filename) );
 
@@ -347,7 +347,7 @@ GIOChannel *io;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	if( homebank_csv_file_chooser(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_SAVE, &filename) == TRUE )
+	if( homebank_csv_file_chooser(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_SAVE, &filename, NULL) == TRUE )
 	{
 
 		DB( g_print(" + filename is %s\n", filename) );
@@ -730,7 +730,8 @@ guint i, row;
 
 	gtk_dialog_set_has_separator(GTK_DIALOG (window), FALSE);
 	
-	homebank_window_set_icon_from_file(GTK_WINDOW (window), "budget.svg");
+	//homebank_window_set_icon_from_file(GTK_WINDOW (window), "budget.svg");
+	gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_BUDGET);
 
 	//store our window private data
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)&data);
