@@ -102,7 +102,7 @@ struct defoperation_data *data;
 Operation *entry;
 gchar *tagstr, *txt;
 
-	DB( g_printf("(defoperation) set\n") );
+	DB( g_printf("(ui_operation) set\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -160,7 +160,7 @@ gchar *txt;
 gdouble value;
 gint active;
 
-	DB( g_printf("(defoperation) get\n") );
+	DB( g_printf("(ui_operation) get\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -170,7 +170,7 @@ gint active;
 
 	/* look and store for a child transfer operation */
 	child = NULL;	
-	if( entry->paymode == PAYMODE_PERSTRANSFER && data->type == OPERATION_EDIT_MODIFY )
+	if( entry->paymode == PAYMODE_INTXFER && data->type == OPERATION_EDIT_MODIFY )
 	{
 		DB( g_print(" search: %d %s %f %d=>%d\n", entry->date, entry->wording, entry->amount, entry->account, entry->dst_account) );
 
@@ -209,7 +209,7 @@ gint active;
 	entry->amount = value;
 
 	/* for internal transfer add, amount must be expense */
-	if( entry->paymode == PAYMODE_PERSTRANSFER && data->type == OPERATION_EDIT_ADD )
+	if( entry->paymode == PAYMODE_INTXFER && data->type == OPERATION_EDIT_ADD )
 	{
 		if( entry->amount > 0 )
 			entry->amount *= -1;
@@ -284,7 +284,7 @@ void defoperation_set_operation(GtkWidget *widget, Operation *ope)
 struct defoperation_data *data;
 
 
-	DB( g_printf("(defoperation) set operation\n") );
+	DB( g_printf("(ui_operation) set out operation\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -334,7 +334,7 @@ static void defoperation_toggleamount(GtkWidget *widget, gpointer user_data)
 struct defoperation_data *data;
 gdouble value;
 
-	DB( g_printf("(defoperation) toggleamount\n") );
+	DB( g_printf("(ui_operation) toggleamount\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -354,7 +354,7 @@ struct defoperation_data *data;
 gint payment;
 gint page;
 
-	DB( g_printf("(defoperation) paymode change\n") );
+	DB( g_printf("(ui_operation) paymode change\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -366,18 +366,18 @@ gint page;
 	{
 	gboolean expense = (gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount)) > 0 ? FALSE : TRUE);
 
-		DB( g_print(" -> payment: %d\n", PAYMODE_CHEQUE) );
+		DB( g_print(" -> payment: %d\n", PAYMODE_CHECK) );
 		DB( g_print(" -> expense: %d\n", expense) );
-		DB( g_print(" -> acc is: %d\n", gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_acc)) ) );
+		DB( g_print(" -> acc is: %d\n", ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_acc)) ) );
 
-		if(payment == PAYMODE_CHEQUE)
+		if(payment == PAYMODE_CHECK)
 		{
 
 
 			if(expense == TRUE)
 			{
 			Account *acc;
-			gint active = gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_acc));
+			gint active = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_acc));
 			guint cheque;
 			gchar *cheque_str;
 
@@ -397,9 +397,9 @@ gint page;
 	}
 
 
-	if(payment == PAYMODE_CHEQUE)
+	if(payment == PAYMODE_CHECK)
 		page = 1;
-	if(payment == PAYMODE_PERSTRANSFER)
+	if(payment == PAYMODE_INTXFER)
 		page = 2;
 
 	DB( g_printf(" payment: %d, page: %d\n", payment, page) );
@@ -414,7 +414,7 @@ static void defoperation_update_accto(GtkWidget *widget, gpointer user_data)
 struct defoperation_data *data;
 guint kacc;
 
-	DB( g_printf("(defoperation) update accto\n") );
+	DB( g_printf("(ui_operation) update accto\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -436,7 +436,7 @@ struct defoperation_data *data;
 gboolean sensitive;
 	guint kacc, kdst;
 
-	DB( g_printf("(defoperation) update transfer\n") );
+	DB( g_printf("(ui_operation) update transfer\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -447,7 +447,7 @@ gboolean sensitive;
 	if(kacc == 0) sensitive = FALSE;
 
 	/* coherent seizure */
-	if( gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode)) == PAYMODE_PERSTRANSFER )
+	if( gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode)) == PAYMODE_INTXFER )
 	{
 
 		kdst = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_accto));
@@ -474,11 +474,11 @@ static void defoperation_update(GtkWidget *widget, gpointer user_data)
 struct defoperation_data *data;
 gboolean sensitive, bool;
 
-	DB( g_printf("(defoperation) update\n") );
+	DB( g_printf("(ui_operation) update\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 	//window = gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW);
-	//DB( g_printf("(defoperation) widget=%08lx, window=%08lx, inst_data=%08lx\n", treeview, window, data) );
+	//DB( g_printf("(ui_operation) widget=%08lx, window=%08lx, inst_data=%08lx\n", treeview, window, data) );
 
 	//valid & remind are exclusive
 	bool  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_valid));
@@ -491,7 +491,7 @@ gboolean sensitive, bool;
 	sensitive = TRUE;
 	if( data->type == OPERATION_EDIT_MODIFY && data->ope !=NULL )
 	{
-		if( data->ope->paymode == PAYMODE_PERSTRANSFER )
+		if( data->ope->paymode == PAYMODE_INTXFER )
 		{
 			sensitive = FALSE;
 		}
@@ -513,7 +513,7 @@ Operation *entry;
 Archive *arc;
 gint n_arc;
 
-	DB( g_printf("(defoperation) fill from\n") );
+	DB( g_printf("(ui_operation) fill from\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 	entry = data->ope;
@@ -552,7 +552,7 @@ static void defoperation_update_child_transfer(Operation *src, Operation *dst)
 Account *acc;
 gboolean active;
 
-	DB( g_print("(defoperation) update child transfer\n") );
+	DB( g_print("(ui_operation) update child transfer\n") );
 
 	/* update the child transfer */
 	dst->date     = src->date;
@@ -583,7 +583,7 @@ void defoperation_dispose(GtkWidget *widget, gpointer user_data)
 {
 struct defoperation_data *data;
 
-	DB( g_printf("(defoperation) dispose\n") );
+	DB( g_printf("(ui_operation) dispose\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -599,7 +599,7 @@ static gboolean defoperation_cleanup(struct defoperation_data *data, gint result
 {
 gboolean doupdate = FALSE;
 
-	DB( g_printf("(defoperation) cleanup\n") );
+	DB( g_printf("(ui_operation) cleanup\n") );
 
 	if(result == GTK_RESPONSE_ACCEPT)
 	{
@@ -620,7 +620,7 @@ gboolean doupdate = FALSE;
 static void defoperation_setup(struct defoperation_data *data)
 {
 
-	DB( g_printf("(defoperation) setup\n") );
+	DB( g_printf("(ui_operation) setup\n") );
 
     gtk_window_set_title (GTK_WINDOW (data->window), _(CYA_OPERATION[data->type]));
 
@@ -820,6 +820,9 @@ struct defoperation_data *data;
 GtkWidget *window, *hbox, *mainbox, *table, *label, *widget;
 GtkWidget *alignment;
 
+	DB( g_printf("(ui_operation) new\n") );
+
+
 	data = g_malloc0(sizeof(struct defoperation_data));
 	if(!data) return NULL;
 
@@ -839,9 +842,6 @@ GtkWidget *alignment;
 			GTK_STOCK_OK,
 			GTK_RESPONSE_ACCEPT,
 		NULL);
-
-		//set the window icon
-		homebank_window_set_icon_from_file(GTK_WINDOW (window), "ope_edit.svg");
 	}
 	else
 	{
@@ -851,18 +851,30 @@ GtkWidget *alignment;
 			GTK_STOCK_CLOSE,
 		    GTK_RESPONSE_REJECT,
 		NULL);
-
-		//set the window icon
-		homebank_window_set_icon_from_file(GTK_WINDOW (window), "ope_add.svg");
 	}
 
 	gtk_dialog_set_has_separator(GTK_DIALOG (window), FALSE);
 
-	//gtk_window_set_icon_from_file(GTK_WINDOW (window), "./pixmaps/archive.png", NULL);
+	switch(type)
+	{
+		case OPERATION_EDIT_ADD:
+			//homebank_window_set_icon_from_file(GTK_WINDOW (window), "ope_add.svg");
+			gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_OPE_ADD);
+			break;
+		case OPERATION_EDIT_INHERIT:
+			//homebank_window_set_icon_from_file(GTK_WINDOW (window), "ope_herit.svg");
+			gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_OPE_HERIT);
+			break;
+		case OPERATION_EDIT_MODIFY:
+			//homebank_window_set_icon_from_file(GTK_WINDOW (window), "ope_edit.svg");
+			gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_OPE_EDIT);
+			break;
+	}
+
 
 	//store our window private data
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)data);
-	DB( g_printf("(defoperation) window=%08lx, inst_data=%08lx\n", window, data) );
+	DB( g_printf(" -> window=%08lx, inst_data=%08lx\n", window, data) );
 
 	data->window = window;
 
