@@ -46,11 +46,13 @@ struct defpref_data
 	GtkWidget	*image;
 
 	GtkWidget	*CY_toolbar;
-	//GtkWidget	*NB_image_size;
-
+	GtkWidget	*CY_colors;
+	GtkWidget	*CM_custom_colors;
 	GtkWidget	*CP_exp_color;
 	GtkWidget	*CP_inc_color;
 	GtkWidget	*CP_warn_color;
+	GtkWidget	*CM_ruleshint;
+
 	GtkWidget	*LV_opecolumns;
 	GtkWidget	*BT_go_up;
 	GtkWidget	*BT_go_down;
@@ -62,7 +64,7 @@ struct defpref_data
 	GtkWidget	*ST_path_export, *BT_path_export;
 
 	GtkWidget	*CM_load_last;
-	
+	GtkWidget	*CM_show_splash;
 	GtkWidget	*CM_herit_date;
 
 	//GtkWidget	*ST_path_navigator;
@@ -142,13 +144,13 @@ GdkPixbuf *pref_pixbuf[PREF_MAX];
 
 
 static gchar *pref_pixname[PREF_MAX] = {
-"prf_general.svg",
-"prf_interface.svg",
-"prf_columns.svg",
-"prf_display.svg",
+"prf-general",
+"prf-interface",
+"prf-columns",
+"prf-display",
 //"prf_help.svg",
-"prf_euro.svg",
-"prf_report.svg"
+"prf-euro",
+"prf-report"
 //"prf_charts.svg"
 };
 
@@ -172,6 +174,15 @@ N_("Text beside icons"),
 NULL
 };
 
+gchar *CYA_TANGO_COLORS[] = {
+"----",
+N_("Tango light"),
+N_("Tango medium"),
+N_("Tango dark"),
+NULL
+};
+
+
 extern gchar *CYA_RANGE[];
 
 typedef struct
@@ -486,8 +497,61 @@ gint country;
 
 }
 
+/*
+** set preset colors for amount display
+*/
+static void defpref_colorpreset(GtkWidget *widget, gpointer user_data)
+{
+struct defpref_data *data;
+GdkColor color;
+gint preset;
+gchar *expcol, *inccol, *wrncol;
+
+	DB( g_print("(defpref) color preset\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	preset = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_colors));
+
+	switch( preset)
+	{
+		case 1:		//light
+			expcol = LIGHT_EXP_COLOR;
+			inccol = LIGHT_INC_COLOR;
+			wrncol = LIGHT_WARN_COLOR;
+			break;
+		
+		case 2:		//medium
+			expcol = MEDIUM_EXP_COLOR;
+			inccol = MEDIUM_INC_COLOR;
+			wrncol = MEDIUM_WARN_COLOR;
+			break;
+	
+		case 3:	//dark
+		default:
+			expcol = DEFAULT_EXP_COLOR;
+			inccol = DEFAULT_INC_COLOR;
+			wrncol = DEFAULT_WARN_COLOR;
+			break;
+	}
 
 
+	gdk_color_parse(expcol, &color);
+	gtk_color_button_set_color(GTK_COLOR_BUTTON(data->CP_exp_color), &color);
+
+	gdk_color_parse(inccol, &color);
+	gtk_color_button_set_color(GTK_COLOR_BUTTON(data->CP_inc_color), &color);
+
+	gdk_color_parse(wrncol, &color);
+	gtk_color_button_set_color(GTK_COLOR_BUTTON(data->CP_warn_color), &color);
+
+
+}
+
+
+
+
+/*
 static void setGdkColor_from_RGB(GdkColor *color, guint32 value)
 {
 guint	tmp;
@@ -501,7 +565,7 @@ guint	tmp;
 	tmp = value & 0xFF;
 	color->blue  = tmp | tmp<<8;
 }
-
+*/
 
 
 /*
@@ -526,15 +590,19 @@ GdkColor color;
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_toolbar), PREFS->toolbar_style);
 	//gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_image_size), PREFS->image_size);
 
-	setGdkColor_from_RGB(&color, PREFS->color_exp);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_custom_colors), PREFS->custom_colors);
+
+	gdk_color_parse(PREFS->color_exp, &color);
 	gtk_color_button_set_color(GTK_COLOR_BUTTON(data->CP_exp_color), &color);
 
-	setGdkColor_from_RGB(&color, PREFS->color_inc);
+	gdk_color_parse(PREFS->color_inc, &color);
 	gtk_color_button_set_color(GTK_COLOR_BUTTON(data->CP_inc_color), &color);
 
-	setGdkColor_from_RGB(&color, PREFS->color_warn);
+	gdk_color_parse(PREFS->color_warn, &color);
 	gtk_color_button_set_color(GTK_COLOR_BUTTON(data->CP_warn_color), &color);
 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_ruleshint), PREFS->rules_hint);
+
 	#if DOWIZARD == 1
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_runwizard), PREFS->runwizard);
 	#endif
@@ -545,6 +613,7 @@ GdkColor color;
 	//gtk_entry_set_text(GTK_ENTRY(data->ST_path_navigator), PREFS->path_navigator);
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_load_last), PREFS->loadlast);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_show_splash), PREFS->showsplash);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_herit_date), PREFS->heritdate);
 
 	/* display */
@@ -636,15 +705,22 @@ GdkColor color;
 	PREFS->toolbar_style = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_toolbar));
 	//PREFS->image_size = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_image_size));
 
+	PREFS->custom_colors = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_custom_colors));
+
 	gtk_color_button_get_color(GTK_COLOR_BUTTON(data->CP_exp_color), &color);
-	PREFS->color_exp = (color.red & 0x00FF) << 16 | (color.green & 0x00FF) << 8 | (color.blue & 0x00FF);
+	g_free(PREFS->color_exp);
+	PREFS->color_exp = gdk_color_to_string(&color);
 
 	gtk_color_button_get_color(GTK_COLOR_BUTTON(data->CP_inc_color), &color);
-	PREFS->color_inc = (color.red & 0x00FF) << 16 | (color.green & 0x00FF) << 8 | (color.blue & 0x00FF);
+	g_free(PREFS->color_inc);
+	PREFS->color_inc = gdk_color_to_string(&color);
 
 	gtk_color_button_get_color(GTK_COLOR_BUTTON(data->CP_warn_color), &color);
-	PREFS->color_warn = (color.red & 0x00FF) << 16 | (color.green & 0x00FF) << 8 | (color.blue & 0x00FF);
+	g_free(PREFS->color_warn);
+	PREFS->color_warn = gdk_color_to_string(&color);
 	
+	PREFS->rules_hint= gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_ruleshint));
+
 	
 	list_opecolumn_get(GTK_TREE_VIEW(data->LV_opecolumns), PREFS->lst_ope_columns);
 
@@ -660,6 +736,7 @@ GdkColor color;
 	defpref_entry_get_text(data->ST_path_export, &PREFS->path_export);
 
 	PREFS->loadlast  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_load_last));
+	PREFS->showsplash  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_show_splash));
 	PREFS->heritdate = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_herit_date));
 
 	//g_free(PREFS->path_navigator);
@@ -1066,7 +1143,11 @@ gint row;
 	row++;
 	label = make_label(_("_Frac digits:"), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = make_numeric(label, 0.0, 6.0);
+	#if MYDEBUG
+		widget = make_numeric(label, 0.0, 15.0);
+	#else
+		widget = make_numeric(label, 0.0, 6.0);
+	#endif
 	data->NB_num_fracdigits = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
@@ -1149,6 +1230,8 @@ gint row;
 	data->LV_opecolumns = widget;
 	gtk_container_add (GTK_CONTAINER (sw), widget);
 
+	gtk_widget_set_tooltip_text(widget, _("Drag & drop to change the order"));
+
 /*
 	vbox = gtk_vbox_new(FALSE, HB_BOX_SPACING);
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
@@ -1232,6 +1315,20 @@ gint row;
 	gtk_label_set_markup (GTK_LABEL(label), _("<b>Amount colors</b>"));
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 3, row, row+1);
 
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("Uses custom colors"));
+	data->CM_custom_colors = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+
+	row++;
+	label = make_label(_("_Preset:"), 0, 0.5);
+	//----------------------------------------- l, r, t, b
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = make_cycle(label, CYA_TANGO_COLORS);
+	data->CY_colors = widget;
+	//gtk_table_attach_defaults (GTK_TABLE (table), data->CY_option[FILTER_DATE], 1, 2, row, row+1);
+	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+
 	row++;
 	label = make_label(_("_Expense:"), 0, 0.5);
 	//----------------------------------------- l, r, t, b
@@ -1262,6 +1359,17 @@ gint row;
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 	gtk_table_attach_defaults (GTK_TABLE (table), hbox, 2, 3, row, row+1);
 
+	row++;
+	label = make_label(NULL, 0.0, 0.0);
+	gtk_label_set_markup (GTK_LABEL(label), _("<b>Treeview</b>"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 3, row, row+1);
+
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("Show rules hint"));
+	data->CM_ruleshint = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+
+
 	return(container);
 }
 
@@ -1371,6 +1479,11 @@ gint row;
 	data->CM_load_last = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
 
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("Show splash"));
+	data->CM_show_splash = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+
 	row++;
 	label = make_label(NULL, 0.0, 0.0);
 	gtk_label_set_markup (GTK_LABEL(label), _("<b>Transaction</b>"));
@@ -1497,9 +1610,8 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *frame, *image, *label;
 
 	gtk_dialog_set_has_separator(GTK_DIALOG (window), FALSE);
 	
-	//set the window icon
-	//homebank_window_set_icon_from_file(GTK_WINDOW (window), "settings.svg");
-
+	gtk_window_set_icon_name(GTK_WINDOW (window), GTK_STOCK_PREFERENCES);
+	
 	mainvbox = gtk_vbox_new (FALSE, 8);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), mainvbox, TRUE, TRUE, 0);
 
@@ -1610,6 +1722,8 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *frame, *image, *label;
 	g_signal_connect (data.BT_path_import, "pressed", G_CALLBACK (defpref_pathselect), GINT_TO_POINTER(2));
 	g_signal_connect (data.BT_path_export, "pressed", G_CALLBACK (defpref_pathselect), GINT_TO_POINTER(3));
 
+    g_signal_connect (data.CY_colors, "changed", G_CALLBACK (defpref_colorpreset), NULL);
+
 
 	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data.LV_page)), "changed", G_CALLBACK (defpref_selection), notebook);
 
@@ -1696,6 +1810,7 @@ GtkWidget *view;
 GtkCellRenderer    *renderer;
 GtkTreeViewColumn  *column;
 GtkTreeIter    iter;
+GtkWidget *cellview;
 gint i;
 
 	/* create list store */
@@ -1728,18 +1843,20 @@ gint i;
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 
+	cellview = gtk_cell_view_new ();
+	
 	//populate our combobox model
 	for(i=0;i<PREF_MAX;i++)
 	{
 	GdkPixbuf *small_pixbuf = NULL;
 	
 		gtk_list_store_append(store, &iter);
-		
+
+		/*
 		if( pref_pixbuf[i] )
-			small_pixbuf = gdk_pixbuf_scale_simple (pref_pixbuf[i],
-                                                24, 24,
-                                                GDK_INTERP_BILINEAR);
-		
+			small_pixbuf = gdk_pixbuf_scale_simple (pref_pixbuf[i], 24, 24, GDK_INTERP_BILINEAR);
+		*/
+		small_pixbuf = gtk_widget_render_icon (cellview, pref_pixname[i], GTK_ICON_SIZE_DND, NULL);
 		
 		gtk_list_store_set(store, &iter,
 			LST_PREF_SMALLPIXBUF, small_pixbuf,
@@ -1749,6 +1866,8 @@ gint i;
 			-1);
 	}
 
+	gtk_widget_destroy (cellview);
+
 	return(view);
 }
 
@@ -1768,28 +1887,17 @@ guint i;
 void load_pref_icons(void)
 {
 //GError *error = NULL;
+GtkWidget *cellview;
 guint i;
 
+	cellview = gtk_cell_view_new ();
+	
 	for(i=0;i<PREF_MAX;i++)
 	{
-	gchar *pathfilename;
-
-	pathfilename = g_build_filename(homebank_app_get_pixmaps_dir(), pref_pixname[i], NULL);
-
-	DB( g_print("loading %s\n", pathfilename) );
-
-		pref_pixbuf[i] = gdk_pixbuf_new_from_file(pathfilename, NULL);
-		//pref_pixbuf[i] = gdk_pixbuf_new_from_file_at_size(pathname, 24, 24, NULL);
-		/*
-		if (error)
-		{
-			g_warning ("Could not load icon: %s\n", error->message);
-			g_error_free(error);
-			error = NULL;
-		}
-		*/
-		g_free (pathfilename);
+		pref_pixbuf[i] = gtk_widget_render_icon (cellview, pref_pixname[i], GTK_ICON_SIZE_DIALOG, NULL);
 	}
+
+	gtk_widget_destroy (cellview);
 }
 
 // -------------------------------
@@ -1798,19 +1906,20 @@ static struct {
 	gint		id;
 } ope_list_columns[] = {
 
-//	{	N_(""), COL_OPE_STATUS,		},
-//	{	N_(""), COL_OPE_DATE,		},
-	{	N_("Info"    ), COL_OPE_INFO,		},
-	{	N_("Payee"   ), COL_OPE_PAYEE,		},
-	{	N_("Description" ), COL_OPE_WORDING,	},
-	{	N_("Amount"  ), COL_OPE_AMOUNT,		},
-	{	N_("Expense" ), COL_OPE_EXPENSE,	},
-	{	N_("Income"  ), COL_OPE_INCOME,		},
-	{	N_("Category"), COL_OPE_CATEGORY,	},
-	{	N_("Tags"), COL_OPE_TAGS,	},
+	{	NULL, LST_DSPOPE_DATAS,		},
+	{	NULL, LST_DSPOPE_STATUS,		},
+	{	NULL, LST_DSPOPE_DATE,		},
+	{	N_("Info"    ), LST_DSPOPE_INFO,		},
+	{	N_("Payee"   ), LST_DSPOPE_PAYEE,		},
+	{	N_("Description" ), LST_DSPOPE_WORDING,	},
+	{	N_("Amount"  ), LST_DSPOPE_AMOUNT,		},
+	{	N_("Expense" ), LST_DSPOPE_EXPENSE,	},
+	{	N_("Income"  ), LST_DSPOPE_INCOME,		},
+	{	N_("Category"), LST_DSPOPE_CATEGORY,	},
+	{	N_("Tags"), LST_DSPOPE_TAGS,	},
 };
 
-static gint n_ope_list_columns = G_N_ELEMENTS (ope_list_columns);
+//static gint n_ope_list_columns = G_N_ELEMENTS (ope_list_columns);
 
 static void
 fixed_toggled (GtkCellRendererToggle *cell,
@@ -1837,8 +1946,7 @@ fixed_toggled (GtkCellRendererToggle *cell,
 }
 
 
-
-static void list_opecolumn_get(GtkTreeView *treeview, gboolean *columns)
+static void list_opecolumn_get(GtkTreeView *treeview, gint *columns)
 {
 GtkTreeModel *model;
 GtkTreeIter	iter;
@@ -1858,12 +1966,14 @@ gint i, id;
 
 		DB( g_print("list_opecolumn_get %d: %d\n",id, visible) );
 	
-		columns[i+2] = visible;
+		columns[i+2] = visible == TRUE ? id : -id;
 
 		 /* Make iter point to the next row in the list store */
 		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
 		i++;
 	}
+	
+	
 
 }
 
@@ -1896,7 +2006,6 @@ GtkCellRenderer    *renderer;
 GtkTreeViewColumn  *column;
 GtkTreeIter    iter;
 gint i;
-gboolean visible;
 
 	/* create list store */
 	store = gtk_list_store_new(
@@ -1907,9 +2016,28 @@ gboolean visible;
 		);
 
 	/* populate */
+	for(i=0; i < NUM_LST_DSPOPE-1 ; i++ )
+	{
+	gint id = ABS(PREFS->lst_ope_columns[i]);
+		
+		DB( g_print("pos:%d id:%d %s\n", i, id, ope_list_columns[id].name) );
+		
+		if( id > LST_DSPOPE_DATE )
+		{
+			gtk_list_store_append (store, &iter);
+			gtk_list_store_set (store, &iter,
+				COLUMN_VISIBLE, (PREFS->lst_ope_columns[i] > 0) ? TRUE : FALSE,
+		  		COLUMN_NAME, ope_list_columns[id].name,
+		  		COLUMN_ID  , ope_list_columns[id].id,
+		  		-1);
+		}
+	}
+
+
+/* old code
 	for (i = 0; i < n_ope_list_columns; i++)
 	{
-		visible = PREFS->lst_ope_columns[ope_list_columns[i].id];
+		visible = (PREFS->lst_ope_columns[ope_list_columns[i].id] > 0) ? TRUE : FALSE;
 		
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
@@ -1918,7 +2046,7 @@ gboolean visible;
       		COLUMN_ID  , ope_list_columns[i].id,
       		-1);
 	}
-
+*/
 
 
 	//treeview
@@ -1944,6 +2072,9 @@ gboolean visible;
 		gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 
+	gtk_tree_view_set_reorderable (GTK_TREE_VIEW(view), TRUE);
+
+
 	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), "changed", G_CALLBACK (list_opecolumn_selection), NULL);
 
 
