@@ -130,6 +130,7 @@ static void account_action_createarchive(GtkAction *action, gpointer user_data);
 
 static void account_action_exportcsv(GtkAction *action, gpointer user_data);
 
+static void account_action_assign(GtkAction *action, gpointer user_data);
 static void account_populate(GtkWidget *view);
 static void account_action(GtkWidget *widget, gpointer user_data);
 static void account_toggle(GtkWidget *widget, gpointer user_data);
@@ -155,21 +156,23 @@ static GtkActionEntry entries[] = {
   /* name, stock id, label */
   { "AccountMenu"  , NULL, N_("_Account") },
   { "OperationMenu", NULL, N_("Transacti_on") },
+  { "ActionsMenu"  , NULL, N_("_Actions") },
   { "ToolsMenu"    , NULL, N_("_Tools") },
 
-  { "Close"      , GTK_STOCK_CLOSE          , N_("_Close")        , NULL, N_("Close the current account"),    G_CALLBACK (account_action_close) },
+  { "Close"        , GTK_STOCK_CLOSE  , N_("_Close")        , NULL, N_("Close the current account"),    G_CALLBACK (account_action_close) },
 
 	/* name, stock id, label, accelerator, tooltip */
-  { "Filter"       , "hb-stock-filter", N_("_Filter..."), NULL,    N_("Open the list filter"), G_CALLBACK (account_action_editfilter) },
+  { "Filter"       , "hb-filter"      , N_("_Filter..."), NULL,    N_("Open the list filter"), G_CALLBACK (account_action_editfilter) },
 
-  { "Add"          , "hb-stock-ope-add", N_("_Add..."), NULL,    N_("Add a new transaction"), G_CALLBACK (account_action_add) },
-  { "Inherit"      , "hb-stock-ope-herit", N_("_Inherit..."), NULL, N_("Inherit from the active transaction"), G_CALLBACK (account_action_inherit) },
-  { "Edit"         , "hb-stock-ope-edit", N_("_Edit..."), NULL, N_("Edit the active transaction"),  G_CALLBACK (account_action_edit) },
-  { "Validate"     , "hb-stock-ope-valid", N_("(In)_Validate"), NULL,    N_("Validate the active transactions"), G_CALLBACK (account_action_validate) },
-  { "Remove"       , "hb-stock-ope-delete", N_("_Remove..."), NULL,    N_("Remove the active transactions"), G_CALLBACK (account_action_remove) },
-  { "MakeArchive"  , NULL, N_("Make an archive..."), NULL,    NULL, G_CALLBACK (account_action_createarchive) },
+  { "Add"          , HB_STOCK_OPE_ADD    , N_("_Add..."), NULL,    N_("Add a new transaction"), G_CALLBACK (account_action_add) },
+  { "Inherit"      , HB_STOCK_OPE_HERIT  , N_("_Inherit..."), NULL, N_("Inherit from the active transaction"), G_CALLBACK (account_action_inherit) },
+  { "Edit"         , HB_STOCK_OPE_EDIT   , N_("_Edit..."), NULL, N_("Edit the active transaction"),  G_CALLBACK (account_action_edit) },
+  { "Validate"     , "hb-ope-valid"      , N_("(In)_Validate"), NULL,    N_("Validate the active transactions"), G_CALLBACK (account_action_validate) },
+  { "Remove"       , HB_STOCK_OPE_DELETE , N_("_Remove..."), NULL,    N_("Remove the active transactions"), G_CALLBACK (account_action_remove) },
+  { "MakeArchive"  , NULL                , N_("Make an archive..."), NULL,    NULL, G_CALLBACK (account_action_createarchive) },
 
-  { "Export"       , NULL, N_("Export CSV..."), NULL,    NULL, G_CALLBACK (account_action_exportcsv) },
+  { "Assign"       , "hb-assign-run"     , N_("Auto. Assignments"), NULL,    N_("Run auto assignments"), G_CALLBACK (account_action_assign) },
+  { "Export"       , "hb-file-export"    , N_("Export CSV..."), NULL,    N_("Export as CSV"), G_CALLBACK (account_action_exportcsv) },
 
 };
 static guint n_entries = G_N_ELEMENTS (entries);
@@ -177,9 +180,11 @@ static guint n_entries = G_N_ELEMENTS (entries);
 static const gchar *ui_info =
 "<ui>"
 "  <menubar name='MenuBar'>"
+
 "    <menu action='AccountMenu'>"
 "      <menuitem action='Close'/>"
 "    </menu>"
+
 "    <menu action='OperationMenu'>"
 "      <menuitem action='Add'/>"
 "      <menuitem action='Inherit'/>"
@@ -190,10 +195,16 @@ static const gchar *ui_info =
 "        <separator/>"
 "      <menuitem action='MakeArchive'/>"
 "    </menu>"
+
+"    <menu action='ActionsMenu'>"
+"      <menuitem action='Assign'/>"
+"        <separator/>"
+"      <menuitem action='Export'/>"
+"    </menu>"
+
 "    <menu action='ToolsMenu'>"
 "      <menuitem action='Filter'/>"
 "        <separator/>"
-"      <menuitem action='Export'/>"
 "    </menu>"
 "  </menubar>"
 
@@ -206,6 +217,9 @@ static const gchar *ui_info =
 "    <toolitem action='Validate'/>"
 "      <separator/>"
 "    <toolitem action='Filter'/>"
+"      <separator/>"
+"    <toolitem action='Assign'/>"
+"    <toolitem action='Export'/>"
 "  </toolbar>"
 "</ui>";
 
@@ -226,7 +240,6 @@ struct account_data *data = user_data;
 }
 
 
-
 static void account_action_editfilter(GtkAction *action, gpointer user_data)
 {
 struct account_data *data = user_data;
@@ -289,6 +302,39 @@ struct account_data *data = user_data;
 }
 
 
+
+static void account_action_assign(GtkAction *action, gpointer user_data)
+{
+struct account_data *data = user_data;
+gint count;
+gboolean usermode = TRUE;
+
+
+	count = transaction_auto_assign(GLOBALS->ope_list, data->accnum);
+	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_ope));
+	GLOBALS->change += count;
+	
+	//inform the user
+	if(usermode == TRUE)
+	{
+	gchar *txt;
+
+		if(count == 0)
+			txt = _("No transaction changed");
+		else
+			txt = _("%d transactions auto assigned");
+
+		homebank_message_dialog(GTK_WINDOW(data->window), GTK_MESSAGE_INFO,
+			_("Auto assigment result"),
+			txt,
+			count);
+	}
+	
+}
+
+
+
+
 /* these 5 functions are independant from account window */
 Operation *
 operation_get_child_transfer(Operation *src)
@@ -304,7 +350,7 @@ Operation *item;
 	while (list != NULL)
 	{
 		item = list->data;
-		if( item->paymode == PAYMODE_PERSTRANSFER)
+		if( item->paymode == PAYMODE_INTXFER)
 		{
 			if( src->date == item->date &&
 			    src->account == item->dst_account &&
@@ -444,7 +490,7 @@ Account *acc;
 	/* todo:move this to operation add
 		store a new cheque number into account ? */
 		
-	if( (newope->info) && (newope->paymode == PAYMODE_CHEQUE) && !(newope->flags & OF_INCOME) )
+	if( (newope->info) && (newope->paymode == PAYMODE_CHECK) && !(newope->flags & OF_INCOME) )
 	{
 	Account *acc;
 	guint cheque;
@@ -470,7 +516,7 @@ Account *acc;
 	da_operation_append(newope);
 	if(treeview != NULL) operation_add_treeview(newope, treeview, accnum);
 
-	if(ope->paymode == PAYMODE_PERSTRANSFER)
+	if(ope->paymode == PAYMODE_INTXFER)
 	{
 		operation_add_transfer(ope, treeview);
 	}
@@ -529,7 +575,7 @@ GIOChannel *io;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	if( homebank_csv_file_chooser(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_SAVE, &filename) == TRUE )
+	if( homebank_csv_file_chooser(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_SAVE, &filename, NULL) == TRUE )
 	{
 
 		DB( g_print(" + filename is %s\n", filename) );
@@ -600,6 +646,7 @@ GIOChannel *io;
 }
 
 
+
 /*
 ** make an archive with the active operation
 */
@@ -673,7 +720,7 @@ gint result, count;
 				else
 					item->wording 		= g_strdup(_("(new archive)"));
 
-				GLOBALS->arc_list = g_list_insert_sorted(GLOBALS->arc_list, item, (GCompareFunc)defarchive_list_sort);
+				GLOBALS->arc_list = g_list_append(GLOBALS->arc_list, item);
 				GLOBALS->change++;
 
 				list = g_list_next(list);
@@ -898,14 +945,14 @@ GList *list;
 	gchar *info;
 
 		date = g_date_new_julian(data->filter->mindate);
-		g_date_strftime (buffer1, 128-1, "%x", date);
+		g_date_strftime (buffer1, 128-1, PREFS->date_format, date);
 		g_date_set_julian(date, data->filter->maxdate);
-		g_date_strftime (buffer2, 128-1, "%x", date);
+		g_date_strftime (buffer2, 128-1, PREFS->date_format, date);
 		g_date_free(date);
 
-		info = g_strdup_printf("%s - %s", buffer1, buffer2);
+		info = g_strdup_printf("<small>%s - %s</small>", buffer1, buffer2);
 
-		gtk_label_set_text(GTK_LABEL(data->TX_info), info);
+		gtk_label_set_markup(GTK_LABEL(data->TX_info), info);
 
 
 		g_free(info);
@@ -943,7 +990,7 @@ gint *indices;
 	}
 
 	/* deal with transfer to be validated also */
-	if( entry->paymode == PAYMODE_PERSTRANSFER )
+	if( entry->paymode == PAYMODE_INTXFER )
 	{
 	Operation *ct;
 		
@@ -1182,7 +1229,7 @@ gboolean result;
 					}
 
 
-					if( ope->paymode == PAYMODE_PERSTRANSFER )
+					if( ope->paymode == PAYMODE_INTXFER )
 					{
 					Operation *ct;
 						
@@ -1277,7 +1324,7 @@ gboolean result;
 					}
 
 					/* v3.4: also remove child transfer */
-					if( entry->paymode == PAYMODE_PERSTRANSFER )
+					if( entry->paymode == PAYMODE_INTXFER )
 					{
 						operation_delete_child_transfer( entry );
 					}
@@ -1328,10 +1375,8 @@ gboolean result;
 
 		case ACTION_ACCOUNT_FILTER:
 		{
-			//debug
-			//create_deffilter_window(data->filter, FALSE);
 
-			if(create_deffilter_window(data->filter, FALSE) == GTK_RESPONSE_ACCEPT)
+			if(create_deffilter_window(data->filter, FALSE) != GTK_RESPONSE_REJECT)
 			{
 				account_populate(data->LV_ope);
 				account_update(data->LV_ope, GINT_TO_POINTER(UF_SENSITIVE+UF_BALANCE));
@@ -1921,8 +1966,6 @@ static gboolean account_dispose(GtkWidget *widget, GdkEvent *event, gpointer use
 	DB( g_printf("(account) delete-event\n") );
 
 
-
-
 	return FALSE;
 }
 
@@ -2022,7 +2065,8 @@ GError *error = NULL;
 	DB( g_printf("(account) new window=%08lx, inst_data=%08lx\n", window, data) );
 
 	//set the window icon
-	homebank_window_set_icon_from_file(GTK_WINDOW (window), "ope_show.svg");
+	//homebank_window_set_icon_from_file(GTK_WINDOW (window), "ope_show.svg");
+	gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_OPE_SHOW );
 
 	mainvbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (window), mainvbox);
