@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2008 Maxime DOYEN
+ *  Copyright (C) 1995-2009 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -24,9 +24,9 @@ GtkWidget *create_account_window(gint accnum, Account *acc);
 void operation_add_treeview(Operation *ope, GtkWidget *treeview, gint accnum);
 void operation_add(Operation *ope, GtkWidget *treeview, gint accnum);
 
-Operation *operation_get_child_transfert(Operation *src);
-void operation_warn_transfert(Operation *src, gchar *msg2);
-void operation_delete_child_transfert(Operation *src);
+Operation *operation_get_child_transfer(Operation *src);
+void operation_warn_transfer(Operation *src, gchar *msg2);
+void operation_delete_child_transfer(Operation *src);
 
 void account_init_window(GtkWidget *widget, gpointer user_data);
 void account_busy(GtkWidget *widget, gboolean state);
