@@ -20,6 +20,53 @@
 #ifndef __HOMEBANK_DSPWALLET_H__
 #define __HOMEBANK_DSPWALLET_H__
 
+struct wallet_data
+{
+	GtkWidget	*window;
+
+	GtkWidget	*toolbar;
+	GtkWidget	*menubar;
+	GtkWidget	*vpaned;
+	
+	GtkWidget	*LV_acc;
+	GtkWidget	*GR_upc;
+	GtkWidget	*LV_upc;
+
+	GtkWidget	*statusbar; /* A pointer to the status bar. */
+	guint statusbar_menu_context_id; /* The context id of the menu bar */
+	guint statusbar_actions_context_id; /* The context id of actions messages */
+
+
+	gchar	*wintitle;
+	gdouble	bank, today, future;
+
+	//struct	Base base;
+
+	Account *acc;
+
+	gint	busy;
+
+	GtkUIManager	*manager;
+	GtkActionGroup *actions;
+
+	GtkRecentManager *recent_manager;
+	GtkWidget *recent_menu;
+
+	/*
+	UBYTE	accnum;
+	UBYTE	pad0;
+	struct	Account *acc;
+
+	ULONG	mindate, maxdate;
+	ULONG	change;
+	ULONG	keyvalue;
+	UBYTE	title[140];
+	UBYTE	Filename[108];
+	UBYTE	csvpath[108];
+	*/
+};
+
+
 GtkWidget *create_wallet_window(GtkWidget *do_widget);
 void wallet_open_internal(GtkWidget *widget, gpointer user_data);
 void wallet_updateacc(GtkWidget *widget, gpointer user_data);
