@@ -1046,10 +1046,13 @@ cairo_text_extents_t extents;
 			valstr = chart_print_int(chart, (gint)curxval);
 			cairo_text_extents(cr, valstr, &extents);
 
+			//DB( g_print("'%s', %f %f %f %f %f %f\n", valstr, extents.x_bearing, extents.y_bearing, extents.width, extents.height, extents.x_advance, extents.y_advance) );
+
 			cairo_set_source_rgb(cr, COLTOCAIRO(102), COLTOCAIRO(102), COLTOCAIRO(102)); 
 			cairo_move_to(cr, chart->l, y + 2 + extents.height);	
 			cairo_show_text(cr, valstr); 
-			cairo_move_to(cr, chart->l + chart->w - extents.width - 1, y + 2 + extents.height);	
+			
+			cairo_move_to(cr, chart->r - extents.x_advance, y + 2 + extents.height);	
 			cairo_show_text(cr, valstr);
 		}
 
@@ -1120,6 +1123,8 @@ gint i;
 			x2 = x + 2;
 			h = (chart->datas1[i] / chart->range) * chart->graph_height;
 			y2 = chart->oy - h;
+			if(chart->datas1[i] < 0.0)
+				y2 += 1;
 			
 			cairo_rectangle(cr, x2, y2, barw-3, h);
 			cairo_fill(cr);
