@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2008 Maxime DOYEN
+ *  Copyright (C) 1995-2009 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -92,7 +92,7 @@ static guint dateentry_signals[LAST_SIGNAL] = {0,};
 
 
 // todo:finish this
-// this is to be able to saise d or d/m or m/d in the gtkdateentry
+// this is to be able to seizure d or d/m or m/d in the gtkdateentry
 
 /* order of these in the current locale */
 static GDateDMY dmy_order[3] = 
@@ -551,11 +551,11 @@ GDateParseTokens pt;
 	switch( pt.num_ints )
 	{
 		case 1:
-			DB( g_print(" -> saised 1 number\n") );
+			DB( g_print(" -> seizured 1 number\n") );
 			g_date_set_day(dateentry->date, pt.n[0]);
 			break;
 		case 2:
-			DB( g_print(" -> saised 2 numbers\n") );
+			DB( g_print(" -> seizured 2 numbers\n") );
 			if( dmy_order[0] != G_DATE_YEAR )
 			{
 				if( dmy_order[0] == G_DATE_DAY )
