@@ -94,6 +94,20 @@ GList *list;
 		}		
 		list = g_list_next(list);
 	}
+	
+	list = g_hash_table_get_values(GLOBALS->h_rul);
+	while (list != NULL)
+	{
+	Assign *entry = list->data;
+
+		if(entry->category == key1)
+		{	
+			entry->category = key2;
+		}		
+		list = g_list_next(list);
+	}
+	g_list_free(list);
+	
 }
 
 
