@@ -37,6 +37,88 @@ extern struct HomeBank *GLOBALS;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
+//todo: this is only a test
+gint transaction_auto_assign(GList *ope_list, guint key)
+{
+GList *l_ope;
+GList *l_rul, *c_rul;
+gint changes = 0;
+
+	l_ope = g_list_first(ope_list);
+	l_rul = g_hash_table_get_values(GLOBALS->h_rul);
+
+	while (l_ope != NULL)
+	{
+	Operation *ope = l_ope->data;
+
+		//DB( g_print("ope '%s' %d, %d\n", ope->wording, ope->payee, ope->category) );
+		
+		if( key == -1 || key == ope->account )
+		{
+		
+		
+			if( ope->payee == 0 && ope->category == 0 )
+			{	
+				c_rul = g_list_first(l_rul);
+				while (c_rul != NULL)
+				{
+				Assign *rul = c_rul->data;
+
+					DB( g_print("search %s in %s\n", rul->name, ope->wording) );
+					if( rul->name != NULL)
+					{
+						if( rul->exact )
+						{				
+							if( g_strrstr(ope->wording, rul->name) != NULL )
+							{
+								DB( g_print(" found case\n") );
+				
+								ope->payee    = rul->payee;
+								ope->category = rul->category;
+
+								ope->flags |= OF_CHANGED;
+								changes++;
+							}
+						}
+						else
+						{
+						gchar *word   = g_utf8_casefold(ope->wording, -1);
+						gchar *needle = g_utf8_casefold(rul->name, -1);
+			
+							if( g_strrstr(word, needle) != NULL )
+							{
+								DB( g_print(" found nocase\n") );
+				
+								ope->payee    = rul->payee;
+								ope->category = rul->category;
+					
+								ope->flags |= OF_CHANGED;
+								changes++;
+							}
+		
+			
+			
+						}
+					}
+
+					c_rul = g_list_next(c_rul);
+				}
+			}
+		
+		}
+		
+		l_ope = g_list_next(l_ope);
+	}
+
+	g_list_free(l_rul);
+
+	return changes;
+}
+
+
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
+
 guint
 transaction_count_tags(Operation *ope)
 {
