@@ -20,13 +20,12 @@
 #ifndef __HB_TRANSACTION_H__
 #define __HB_TRANSACTION_H__
 
-guint
-transaction_count_tags(Operation *ope);
+guint transaction_count_tags(Operation *ope);
 
-guint
-transaction_set_tags(Operation *ope, const gchar *tagstring);
+guint transaction_set_tags(Operation *ope, const gchar *tagstring);
 
-gchar *
-transaction_get_tagstring(Operation *ope);
+gchar *transaction_get_tagstring(Operation *ope);
+
+gint transaction_auto_assign(GList *ope_list, guint key);
 
 #endif
