@@ -52,6 +52,8 @@ da_qif_tran_free(QIF_Tran *item)
 	{
 		if(item->date != NULL)
 			g_free(item->date);
+		if(item->info != NULL)
+			g_free(item->info);
 		if(item->payee != NULL)
 			g_free(item->payee);
 		if(item->memo != NULL)
@@ -117,36 +119,48 @@ hb_qif_parser_get_amount(gchar *string)
 {
 gdouble amount;
 gint l, i;
-char *new_str, *p;
+char *new_str, *p, sep;
+gint cc = 0;
+gint pc = 0;
 
 	amount = 0.0;
 
-	// is there a non digit char at length-3 pos, it should be a decimal separator
 	l = strlen(string);
-	
-	if( !g_ascii_isdigit( string[l-3] && string[l-3] != '-' ))
+
+	/* count comma and point digits */
+	for(i=0;i<l;i++)
 	{
-		//DB( g_print(" -> %s it seems a decimal char is %c (%d)\n", string, string[l-3],l ));	
+		if( string[i] == ',') cc++;
+		else
+			if( string[i] == '.') pc++;
+	}		
 
-		new_str = g_malloc (l+1);
-		p = new_str;
-		for(i=0;i<l;i++)
+	/* determine decimal separator */
+	sep = '.';
+	if(cc == 1)
+		sep = ',';
+	
+	 DB( g_print(" %s comma: %d, point: %d, sep:%c\n", string, cc, pc, sep) );
+
+
+	new_str = g_malloc (l+1);
+	p = new_str;
+	for(i=0;i<l;i++)
+	{
+		if( g_ascii_isdigit( string[i] ) || string[i] == '-' )
 		{
-			if( g_ascii_isdigit( string[i] ) || string[i] == '-' )
-			{
-				*p++ = string[i];
-			}
-			else
-			if( string[i] == string[l-3] )
-				*p++ = '.';
-				
+			*p++ = string[i];
 		}
-		*p++ = '\0';
-		amount = g_ascii_strtod(new_str, NULL);
-		g_free(new_str);
+		else
+			if( string[i] == sep )
+				*p++ = '.';
 	}
+	*p++ = '\0';
+	amount = g_ascii_strtod(new_str, NULL);
 
-	//DB( g_print(" -> amount is '%s'  %.2f\n", string, amount ));	
+	DB( g_print(" -> amount is '%s' => '%s' %f\n", string, new_str, amount) );
+
+	g_free(new_str);
 
 	return amount;
 }
@@ -478,6 +492,30 @@ QIF_Tran tran = { 0 };
 					}
 					else
 
+				// cleared status
+					if(g_str_has_prefix(tmpstr, "C"))
+					{
+						if(g_str_has_prefix(value, "X") || g_str_has_prefix(value, "R") )
+						{
+							tran.validated = TRUE;
+						}
+						else
+							tran.validated = FALSE;
+					}
+					else
+
+				// check num or reference number
+					if(g_str_has_prefix(tmpstr, "N"))
+					{
+						if(*value != '\0')
+						{
+							g_free(tran.info);
+							g_strstrip(value);
+							tran.info = g_strdup(value);
+						}
+					}
+					else
+
 				// payee
 					if(g_str_has_prefix(tmpstr, "P"))
 					{
@@ -581,7 +619,7 @@ Operation *item;
 	while (list != NULL)
 	{
 		item = list->data;
-		if( item->paymode == PAYMODE_PERSTRANSFER)
+		if( item->paymode == PAYMODE_INTXFER)
 		{
 			if( src->date == item->date &&
 			    src->account == item->dst_account &&
@@ -664,6 +702,7 @@ GList *list = NULL;
 		}
 
 		newope->wording		 = g_strdup(item->memo);
+		newope->info		 = g_strdup(item->info);
 		newope->amount		 = item->amount;
 		
 		
@@ -699,7 +738,7 @@ GList *list = NULL;
 				}
 				
 				newope->dst_account = accitem->key;
-				newope->paymode = PAYMODE_PERSTRANSFER;
+				newope->paymode = PAYMODE_INTXFER;
 				
 				
 				g_free(accname);
@@ -748,6 +787,10 @@ GList *list = NULL;
 		if( newope->amount > 0)
 			newope->flags |= OF_INCOME;
 
+		if( item->validated )
+			newope->flags |= OF_VALID;
+
+
 		child = NULL;
 		
 		child = account_qif_get_child_transfer(newope, list);
@@ -835,7 +878,9 @@ size_t rc;
 					
 					g_string_append_printf (buffer, "T%s\n", amountbuf);
 				
-					if( trans->paymode == PAYMODE_CHEQUE)
+					g_string_append_printf (buffer, "C%s\n", trans->flags & OF_VALID ? "R" : "");
+				
+					if( trans->paymode == PAYMODE_CHECK)
 						g_string_append_printf (buffer, "N%s\n", trans->info);
 
 					payee = da_pay_get(trans->payee);
@@ -850,7 +895,7 @@ size_t rc;
 						// LCategory of transaction/Class of transaction
 						// L[Transfer account]/Class of transaction
 
-					if( trans->paymode == PAYMODE_PERSTRANSFER && trans->account == item->key)
+					if( trans->paymode == PAYMODE_INTXFER && trans->account == item->key)
 					{
 						g_string_append_printf (buffer, "L[%s]\n", item->name);
 					}
