@@ -32,12 +32,14 @@ struct _QifContext
 typedef struct _qif_tran	QIF_Tran;
 struct _qif_tran
 {
-	gchar	*date;
-	gdouble	amount;
-	gchar	*payee;
-	gchar	*memo;
-	gchar	*category;
-	gchar	*account;
+	gchar		*date;
+	gdouble		amount;
+	gboolean	validated;
+	gchar		*info;
+	gchar		*payee;
+	gchar		*memo;
+	gchar		*category;
+	gchar		*account;
 };
 
 
