@@ -22,24 +22,14 @@
 
 #define QIF_UNKNOW_ACCOUNT_NAME "(unknown)"
 
-enum
-{
-	FILETYPE_UNKNOW,
-	FILETYPE_AMIGA_HB,
-	FILETYPE_CSV_HB,
-	FILETYPE_OFX,
-	FILETYPE_QIF,
-	NUM_FILETYPE
-};
+
 
 
 enum
 {
 	PAGE_INTRO,
 	PAGE_FILE,
-	PAGE_FILECONTENT,
-	PAGE_ACCOUNT,
-	PAGE_TRANSACTION,
+	PAGE_OPTIONS,
 	PAGE_CONFIRM,
 	NUM_PAGE
 };
@@ -48,9 +38,9 @@ enum
 typedef struct _ImportContext ImportContext;
 struct _ImportContext
 {
-	GList		*trans_list;
+	GList		*trans_list;		// trn storage
 	gint 		cnt_initial_acc;	//max key account when start
-	gint		cnt_new_acc;
+	gint		cnt_new_acc;		//
 	gint		cnt_new_ope;
 	gint		cnt_new_pay;
 	gint		cnt_new_cat;
@@ -73,13 +63,16 @@ struct import_data
 	GtkWidget	*assistant;
 	GtkWidget	*pages[NUM_PAGE];
 
+	GdkPixbuf	*head_pixbuf;
+	GdkPixbuf	*side_pixbuf;
+	
 	GtkWidget	*filechooser;
 	GtkWidget	*user_info;
 	GtkWidget	*ok_image;
 	GtkWidget	*ko_image;
 
 	GtkWidget	*TX_filename;
-	GtkWidget	*TX_details;
+	GtkWidget	*TX_filedetails;
 
 //	GtkWidget	*LA_acc;
 	GtkWidget	*NB_decay;
@@ -91,13 +84,20 @@ struct import_data
 	GtkWidget	*imported_ope;
 	GtkWidget	*duplicat_ope;
 	
-	GtkWidget	*last_info;
+	GtkWidget	*TX_acc_upd;
+	GtkWidget	*TX_acc_new;
+	GtkWidget	*TX_trn_imp;
+	GtkWidget	*TX_trn_nop;
+	GtkWidget	*TX_trn_asg;
+
 	
 	gchar		*filename;
 	guint		filetype;
 
-	guint		imported;
-	guint		total;
+	/* count imported items */
+	guint		imp_cnt_acc;
+	guint		imp_cnt_trn;
+	guint		imp_cnt_asg;
 
 	gboolean	valid;
 
