@@ -20,6 +20,31 @@
 #ifndef __LIST_ACCOUNT__H__
 #define __LIST_ACCOUNT__H__
 
+/* lst acc datatype */
+enum
+{
+	DSPACC_TYPE_NORMAL,
+	DSPACC_TYPE_HEADER,
+	DSPACC_TYPE_SUBTOTAL,
+	DSPACC_TYPE_TOTAL
+};
+
+
+/* list display account (wallet) */
+enum
+{
+	LST_DSPACC_DATAS,
+	LST_DSPACC_DATATYPE,
+	LST_DSPACC_STATE,	/* fake column */
+	LST_DSPACC_NAME,	/* fake column */
+	LST_DSPACC_TYPE,	/* fake column */
+	LST_DSPACC_BANK,
+	LST_DSPACC_TODAY,
+	LST_DSPACC_FUTURE,
+	NUM_LST_DSPACC
+};
+
+
 GtkWidget *create_list_account(void);
 
 #endif /* __LIST_ACCOUNT__H__ */
