@@ -24,6 +24,17 @@
 #include "hb_transaction.h"
 #include "list_operation.h"
 
+/****************************************************************************/
+/* Debug macros                                                             */
+/****************************************************************************/
+#define MYDEBUG 0
+
+#if MYDEBUG
+#define DB(x) (x);
+#else
+#define DB(x);
+#endif
+
 /* our global datas */
 extern struct HomeBank *GLOBALS;
 extern struct Preferences *PREFS;
@@ -72,7 +83,15 @@ static   gint
 			break;
 
 		case LST_DSPOPE_PAYEE:
-			ret = ope1->payee - ope2->payee;
+			{
+			Payee *p1, *p2;
+			
+				p1 = da_pay_get(ope1->payee);
+				p2 = da_pay_get(ope2->payee);
+				
+				if( p1->name && p2->name ) 
+					ret = g_utf8_collate(p1->name, p2->name);
+			}
 			break;
 
 		case LST_DSPOPE_WORDING:
@@ -88,9 +107,41 @@ static   gint
 			break;
 
 		case LST_DSPOPE_CATEGORY:
-			ret = ope1->category - ope2->category;
+			{
+			Category *c1, *c2;
+			gchar *name1, *name2;
+			
+				c1 = da_cat_get(ope1->category);
+				c2 = da_cat_get(ope2->category);
+				if( c1 != NULL && c2 != NULL )
+				{
+					name1 = da_cat_get_fullname(c1);
+					name2 = da_cat_get_fullname(c2);
+				
+					if(name1 != NULL && name2 != NULL)
+						ret = g_utf8_collate(name1, name2);
+					
+					g_free(name2);
+					g_free(name1);
+				}				
+			}
 			break;
 
+		case LST_DSPOPE_TAGS:
+		{
+		gchar *t1, *t2;
+		
+			t1 = transaction_get_tagstring(ope1);
+			t2 = transaction_get_tagstring(ope2);
+			if( t1 != NULL && t2 != NULL )
+			{
+				ret = g_utf8_collate(t1, t2);
+			}
+			g_free(t1);
+			g_free(t2);
+		}
+		break;
+
 		default:
 			g_return_val_if_reached(0);
     }
@@ -202,10 +253,15 @@ gchar *str;
 	gtk_tree_model_get(model, iter, LST_DSPOPE_DATAS, &ope, -1);
 
 	if(ope->tags != NULL)
+	{
 		str = transaction_get_tagstring(ope);
+		g_object_set(renderer, "text", str, NULL);
+		g_free(str);
+	}
 	else
-		str = "";
-	g_object_set(renderer, "text", str, NULL);
+		g_object_set(renderer, "text", "", NULL);
+
+
 }
 
 
@@ -227,7 +283,9 @@ static void ope_amount_cell_data_function (GtkTreeViewColumn *col, GtkCellRender
 {
 Operation *ope;
 gint column = GPOINTER_TO_INT(user_data);
+gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 gint type;
+gchar *color;
 
 	// get the operation
 	gtk_tree_model_get(model, iter, LST_DSPOPE_DATAS, &ope, -1);
@@ -240,27 +298,14 @@ gint type;
 	}
 	else
 	{
-	GtkWidget *widget;
-	gchar   buf[128];
-	gboolean minor;
-	gchar *markuptxt;
-	guint32 color;
-
-		widget = g_object_get_data(G_OBJECT(model), "minor");
-		if(GTK_IS_TOGGLE_BUTTON(widget))
-		{
-			minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
-		}
-		else
-			minor = 0;
-
-		mystrfmon(buf, 127, ope->amount, minor);
-
-		color = (ope->flags & OF_INCOME) ? PREFS->color_inc : PREFS->color_exp;
-		markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", color, buf);
-		g_object_set(renderer, "markup", markuptxt, NULL);
-		g_free(markuptxt);
+		mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, ope->amount, GLOBALS->minor);
+		
+		color = get_normal_color_amount(ope->amount);
 
+		g_object_set(renderer, 
+			"foreground",  color,
+			"text", buf,
+			NULL);
 	}
 }
 
@@ -298,7 +343,7 @@ GtkCellRenderer    *renderer;
 	gtk_tree_view_column_set_title(column, _("Info"));
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_pack_start(column, renderer, FALSE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_info_cell_data_function, GINT_TO_POINTER(1), NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -307,6 +352,7 @@ GtkCellRenderer    *renderer;
 	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_INFO);
 
 	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_reorderable(column, TRUE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 
 	return column;
@@ -326,6 +372,7 @@ GtkCellRenderer    *renderer;
 	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_payee_cell_data_function, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_PAYEE);
 	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_reorderable(column, TRUE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 
 	return column;
@@ -344,6 +391,7 @@ GtkCellRenderer    *renderer;
 	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_wording_cell_data_function, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_WORDING);
 	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_reorderable(column, TRUE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 
 	return column;
@@ -367,6 +415,7 @@ GtkCellRenderer    *renderer;
 	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_amount_cell_data_function, GINT_TO_POINTER(id), NULL);
 	gtk_tree_view_column_set_sort_column_id (column, id);
 	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_reorderable(column, TRUE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 
 	return column;
@@ -388,6 +437,7 @@ GtkCellRenderer    *renderer;
 	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_category_cell_data_function, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_CATEGORY);
 	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_reorderable(column, TRUE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 
 	return column;
@@ -406,17 +456,62 @@ GtkCellRenderer    *renderer;
 	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_tags_cell_data_function, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_TAGS);
 	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_reorderable(column, TRUE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 
 	return column;
 }
 
-static void list_operation_visible_columns(GtkTreeView *treeview, gint *visibility)
+
+static void list_operation_sort_column_changed(GtkTreeSortable *sortable, gpointer user_data)
 {
-GtkTreeViewColumn *column;
-GList *list, *tmp;
-gint i = 0;
 gint id;
+GtkSortType order;
+
+	gtk_tree_sortable_get_sort_column_id(sortable, &id, &order);
+
+	DB( g_print("list_operation_columns_changed %d %d\n", id, order) );
+
+	//here save the transaction list columnid and sort order
+	PREFS->lst_ope_sort_id    = id;
+	PREFS->lst_ope_sort_order = order;
+
+
+
+}
+
+
+
+static GtkTreeViewColumn *list_operation_get_column(GList *list, gint search_id)
+{
+GtkTreeViewColumn *column = NULL;
+GList *tmp;
+gint id;
+
+	tmp = g_list_first(list);
+	while (tmp != NULL)
+	{
+		id = gtk_tree_view_column_get_sort_column_id(tmp->data);
+		if( search_id == id)
+			column = tmp->data;
+			
+		tmp = g_list_next(tmp);
+	}
+
+	return column;
+}
+
+
+//todo: this will not work (mem freed before return)
+/*
+gint *list_operation_get_columns(GtkTreeView *treeview)
+{
+gint columns[NUM_LST_DSPOPE + 1];
+GList *list, *tmp;
+GtkTreeViewColumn *column;
+gint id, i = 0;
+
+	DB( g_print("(list_operation_get_columns)\n") );
 
 	list = gtk_tree_view_get_columns( treeview );
 	tmp = g_list_first(list);
@@ -424,6 +519,63 @@ gint id;
 	{
 		column = tmp->data;
 		id = gtk_tree_view_column_get_sort_column_id(column);
+		columns[i] = gtk_tree_view_column_get_visible (column) ? id : -id;
+	
+		tmp = g_list_next(tmp);
+		i++;
+	}
+	
+
+
+	g_list_free(list );
+
+	return columns;
+}
+*/
+
+static void list_operation_set_columns(GtkTreeView *treeview, gint *visibility)
+{
+GtkTreeViewColumn *column, *base;
+GList *list;
+gint i = 0;
+
+	DB( g_print("(list_operation_set_columns)\n") );
+
+
+	list = gtk_tree_view_get_columns( treeview );
+
+	base = NULL;
+
+	for(i=0; i < NUM_LST_DSPOPE-1 ; i++ )
+	{
+
+		column = list_operation_get_column(list, ABS(visibility[i]));
+		if( column != NULL )
+		{
+	
+			DB( g_print(" - pos:%d col:%d (%s)\n", i, visibility[i], gtk_tree_view_column_get_title(column)) );
+	
+			gtk_tree_view_move_column_after(treeview, column, base);
+			base = column;
+			
+			gtk_tree_view_column_set_visible (column, visibility[i] < 0 ? FALSE : TRUE);
+		
+		}
+		
+	}
+
+
+		/* old code */
+	/*
+	list = gtk_tree_view_get_columns( treeview );
+	tmp = g_list_first(list);
+	while (tmp != NULL)
+	{
+		
+		column = tmp->data;
+		id = gtk_tree_view_column_get_sort_column_id(column);
+		
+		DB( g_print(" - col %d (%s)\n", id, gtk_tree_view_column_get_title(column)) );
 		
 		if( i == (NUM_LST_DSPOPE-1) )
 		{
@@ -432,9 +584,12 @@ gint id;
 		else
 			gtk_tree_view_column_set_visible (column, visibility[i]);
 		
+		
+		
 		tmp = g_list_next(tmp);
 		i++;
 	}
+	*/
 
 	g_list_free(list );
 }
@@ -473,7 +628,7 @@ GtkTreeViewColumn  *column;
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), PREFS->rules_hint);
 	//gtk_tree_view_set_search_column (GTK_TREE_VIEW (treeview),
 	//			       COLUMN_DESCRIPTION);
 
@@ -552,12 +707,22 @@ GtkTreeViewColumn  *column;
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_EXPENSE , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_EXPENSE), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_INCOME  , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_INCOME), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_CATEGORY, ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_CATEGORY), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_TAGS    , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_TAGS), NULL);
+
 
-  /* set initial sort order */
-    gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), LST_DSPOPE_DATE, GTK_SORT_ASCENDING);
 
   /* assign visibility */
-	list_operation_visible_columns(GTK_TREE_VIEW(view), columns);
+	list_operation_set_columns(GTK_TREE_VIEW(view), columns);
+
+  /* set initial sort order */
+    DB( g_print("set sort to %d %d\n", PREFS->lst_ope_sort_id, PREFS->lst_ope_sort_order) );
+    
+    
+    gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), PREFS->lst_ope_sort_id, PREFS->lst_ope_sort_order);
+
+
+	/* signals */
+	g_signal_connect (GTK_TREE_SORTABLE(store), "sort-column-changed", G_CALLBACK (list_operation_sort_column_changed), NULL);
 
 	return(view);
 }
@@ -596,20 +761,19 @@ Account *acc, *dacc;
 static void ope_importamount_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Operation *ope;
+gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
+gchar *color;
 
-	// get the operation
 	gtk_tree_model_get(model, iter, LST_DSPOPE_DATAS, &ope, -1);
 
-	gchar   buf[128];
-	gchar *markuptxt;
-	guint32 color;
+	mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, ope->amount, GLOBALS->minor);
+		
+	color = get_normal_color_amount(ope->amount);
 
-		mystrfmon(buf, 127, ope->amount, 0);
-
-		color = (ope->flags & OF_INCOME) ? PREFS->color_inc : PREFS->color_exp;
-		markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", color, buf);
-		g_object_set(renderer, "markup", markuptxt, NULL);
-		g_free(markuptxt);
+	g_object_set(renderer, 
+			"foreground",  color,
+			"text", buf,
+			NULL);
 
 }
 
