@@ -58,8 +58,11 @@ Payee *pay;
 	gtk_tree_model_get(model, iter,
 		LST_DSPUPC_DATAS, &arc,
 		-1);
+
 	pay = da_pay_get(arc->payee);
-    //g_object_set(renderer, "text", pay->name, NULL);
+
+	if(pay != NULL)    
+    	g_object_set(renderer, "text", pay->name, NULL);
 }
 
 /*
@@ -83,37 +86,20 @@ Archive *arc;
 static void amount_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *item;
-gint type;
+gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
+gchar *color;
 
-	// get the operation
+	gtk_tree_model_get(model, iter, LST_DSPUPC_DATAS, &item, -1);
+	color = get_normal_color_amount(item->amount);
 
-	gtk_tree_model_get(model, iter,
-		LST_DSPUPC_DATAS, &item,
-		-1);
-
-	type = (item->flags & OF_INCOME) ? 1 : -1;
-
-	if( !(item->amount) )
-	{
-		g_object_set(renderer, "markup", NULL, NULL);
-	}
-	else
-	{
-	gchar   buf[128];
-	gchar *markuptxt;
-	guint32 color;
-
-		mystrfmon(buf, 127, item->amount, GLOBALS->minor);
-
-		color = (item->flags & OF_INCOME) ? PREFS->color_inc : PREFS->color_exp;
-		markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", color, buf);
-		g_object_set(renderer, "markup", markuptxt, NULL);
-		g_free(markuptxt);
-
-	}
-	
+	mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, item->amount, GLOBALS->minor);
+	g_object_set(renderer, 
+		"foreground",  color,
+		"text", buf,
+		NULL);
 }
 
+
 /*
 ** remaining cell function
 */
@@ -129,8 +115,6 @@ guint decay;
 
 	decay = item->nextdate - GLOBALS->today;
 
-	//markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", color, buf);
-
 	markuptxt = g_strdup_printf("%d days", decay);
 	
 
@@ -148,7 +132,7 @@ GtkTreeViewColumn  *column;
 
 	/* create list store */
 	store = gtk_list_store_new(
-	  	NUM_LST_DSPACC,
+	  	NUM_LST_DSPUPC,
 		G_TYPE_POINTER,
 		G_TYPE_BOOLEAN,	/* fake column */
 		G_TYPE_BOOLEAN,	/* fake column */
@@ -161,7 +145,7 @@ GtkTreeViewColumn  *column;
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), PREFS->rules_hint);
 	//gtk_tree_view_set_search_column (GTK_TREE_VIEW (treeview),
 	//			       COLUMN_DESCRIPTION);
 
