@@ -24,6 +24,9 @@ gint real_mystrfmon(gchar *outstr, gint outlen, gchar *buf1, struct Currency *cu
 gint mystrfmon_int(gchar *outstr, gint outlen, gdouble value, gboolean minor);
 gint mystrfmon(gchar *outstr, gint outlen, gdouble value, gboolean minor);
 
+gchar *get_normal_color_amount(gdouble value);
+gchar *get_minimum_color_amount(gdouble value, gdouble minvalue);
+
 void hb_label_set_colvalue(GtkLabel *label, gdouble value, gboolean minor);
 
 void get_period_minmax(guint month, guint year, guint32 *mindate, guint32 *maxdate);
