@@ -117,18 +117,6 @@ struct lconv *lc = localeconv();
 }
 
 
-static void homebank_pref_update_to_tango_colors(void)
-{
-	if(PREFS->color_exp == OLD_EXP_COLOR)
-		PREFS->color_exp = DEFAULT_EXP_COLOR;
-
-	if(PREFS->color_inc == OLD_INC_COLOR)
-		PREFS->color_inc  = DEFAULT_INC_COLOR;
-	
-	if(PREFS->color_warn == OLD_WARN_COLOR)
-		PREFS->color_warn = DEFAULT_WARN_COLOR;
-
-}
 
 static void homebank_pref_init_wingeometry(struct WinGeometry *wg, gint l, gint t, gint w, gint h)
 {
@@ -139,6 +127,34 @@ static void homebank_pref_init_wingeometry(struct WinGeometry *wg, gint l, gint
 }
 
 
+void homebank_pref_init_measurement_units(void)
+{
+
+	if(PREFS->imperial_unit == TRUE)
+	{
+		////TRANSLATORS: carcost for distance (Miles)
+		PREFS->car_unit_dist = "%d m.";
+
+		////TRANSLATORS: carcost for volume (Galons)
+		PREFS->car_unit_vol  = "%.2f gal";
+	
+		////TRANSLATORS: carcost label for '100 miles'
+		PREFS->car_unit_100  = "100 miles";
+	}
+	else
+	{
+		////TRANSLATORS: carcost for distance (Kilometer)
+		PREFS->car_unit_dist = "%d km";
+
+		////TRANSLATORS: carcost for volume (Liters)
+		PREFS->car_unit_vol  = "%.2f L";
+	
+		////TRANSLATORS: carcost label for '100 km'
+		PREFS->car_unit_100  = "100 Km";
+	}
+
+}
+
 void homebank_pref_free(void)
 {
 	DB( g_print("\n** (preferences) free\n") );
@@ -146,6 +162,10 @@ void homebank_pref_free(void)
 
 	g_free(PREFS->date_format);
 
+	g_free(PREFS->color_exp);
+	g_free(PREFS->color_inc);
+	g_free(PREFS->color_warn);
+
 	g_free(PREFS->path_wallet);
 	g_free(PREFS->path_import);
 	g_free(PREFS->path_export);
@@ -167,6 +187,7 @@ void homebank_pref_free(void)
 
 void homebank_pref_setdefault(void)
 {
+gint i;
 
 	DB( g_print("\n** (preferences) pref init\n") );
 
@@ -180,17 +201,15 @@ void homebank_pref_setdefault(void)
 	//PREFS->path_navigator = g_strdup(DEFAULT_PATH_NAVIGATOR);
 
 	PREFS->loadlast = TRUE;
+	PREFS->showsplash = TRUE;
 	PREFS->heritdate = FALSE;
 
-	PREFS->color_exp  = DEFAULT_EXP_COLOR;
-	PREFS->color_inc  = DEFAULT_INC_COLOR;
-	PREFS->color_warn = DEFAULT_WARN_COLOR;
-
-	//PREFS->runwizard = TRUE;
-
-	DB( g_print(" + #%x\n", PREFS->color_exp) );
-	DB( g_print(" + #%x\n", PREFS->color_inc) );
-	DB( g_print(" + #%x\n", PREFS->color_warn) );
+	PREFS->toolbar_style = 0;
+	PREFS->custom_colors = TRUE;
+	PREFS->color_exp  = g_strdup(DEFAULT_EXP_COLOR);
+	PREFS->color_inc  = g_strdup(DEFAULT_INC_COLOR);
+	PREFS->color_warn = g_strdup(DEFAULT_WARN_COLOR);
+	PREFS->rules_hint = FALSE;
 
 	/* windows position/size */
 	homebank_pref_init_wingeometry(&PREFS->wal_wg, 0, 0, 640, 480);
@@ -207,15 +226,28 @@ void homebank_pref_setdefault(void)
 
 	homebank_pref_init_monetary();
 
-	PREFS->lst_ope_columns[COL_OPE_STATUS] = TRUE;
-	PREFS->lst_ope_columns[COL_OPE_DATE] = TRUE;
-	PREFS->lst_ope_columns[COL_OPE_INFO] = TRUE;
-	PREFS->lst_ope_columns[COL_OPE_PAYEE] = TRUE;
-	PREFS->lst_ope_columns[COL_OPE_WORDING] = TRUE;
-	PREFS->lst_ope_columns[COL_OPE_AMOUNT] = FALSE;
-	PREFS->lst_ope_columns[COL_OPE_EXPENSE] = TRUE;
-	PREFS->lst_ope_columns[COL_OPE_INCOME] = TRUE;
-	PREFS->lst_ope_columns[COL_OPE_CATEGORY] = TRUE;
+	PREFS->wal_toolbar = TRUE;
+	PREFS->wal_statusbar = TRUE;
+	PREFS->wal_upcoming = TRUE;
+	PREFS->wal_vpaned = 0;
+
+
+	i = 0;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_STATUS;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_DATE;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INFO;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_PAYEE;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_WORDING;
+	PREFS->lst_ope_columns[i++] = -LST_DSPOPE_AMOUNT;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_EXPENSE;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INCOME;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_CATEGORY;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_TAGS;
+
+
+	PREFS->lst_ope_sort_id    = LST_DSPOPE_DATE;
+	PREFS->lst_ope_sort_order = GTK_SORT_ASCENDING;
+
 
 	//PREFS->base_cur.nbdecimal = 2;
 	//PREFS->base_cur.separator = TRUE;
@@ -239,6 +271,9 @@ void homebank_pref_setdefault(void)
 
 	PREFS->chart_legend = FALSE;
 
+
+
+
 }
 
 /*
@@ -355,9 +390,14 @@ static void homebank_pref_get_integer(
 	gint *storage)
 {
 
+	DB( g_print(" search %s in %s\n", key, group_name) );
+
+
 	if( g_key_file_has_key(key_file, group_name, key, NULL) )
 	{
 		*storage = g_key_file_get_integer(key_file, group_name, key, NULL);
+		
+		DB( g_print(" store integer %d for %s at %x\n", *storage, key, *storage) );
 	}
 }
 
@@ -400,7 +440,7 @@ gchar *string;
 		/* free any previous string */
 		if( *storage != NULL )
 		{
-			DB( g_print(" storage was not null, freeing\n") );
+			//DB( g_print(" storage was not null, freeing\n") );
 			
 			g_free(*storage);
 		}
@@ -412,7 +452,7 @@ gchar *string;
 		{
 			*storage = g_strdup(string);
 			
-			DB( g_print(" store '%s' for %s at %x\n", string, key, *storage) );
+			//DB( g_print(" store '%s' for %s at %x\n", string, key, *storage) );
 		}
 	}
 
@@ -455,38 +495,82 @@ GError *error = NULL;
 				gchar *version = g_key_file_get_string (keyfile, group, "Version", NULL);
 				DB( g_print(" version: %s\n", version) );
 
-				//todo x = strtoul(s, 0, 16); converti une chaine hexa en int
-
 				homebank_pref_get_short(keyfile, group, "BarStyle" , &PREFS->toolbar_style);
-				homebank_pref_get_guint32(keyfile, group, "ColorExp" , &PREFS->color_exp);
-				homebank_pref_get_guint32(keyfile, group, "ColorInc" , &PREFS->color_inc);
-				homebank_pref_get_guint32(keyfile, group, "ColorWarn", &PREFS->color_warn);
 
-				#if DOWIZARD == 1
-				homebank_pref_get_boolean(keyfile, group, "RunWizard", &PREFS->runwizard);
-				#endif
+				if(!strcmp("0.2", version))	// retrieve old settings
+				{				
+				guint32 color;
+					
+					homebank_pref_get_guint32(keyfile, group, "ColorExp" , &color);
+					g_free(PREFS->color_exp);
+					PREFS->color_exp = g_strdup_printf("#%06x", color);
 				
+					homebank_pref_get_guint32(keyfile, group, "ColorInc" , &color);
+					g_free(PREFS->color_inc);
+					PREFS->color_inc = g_strdup_printf("#%06x", color);
+
+					homebank_pref_get_guint32(keyfile, group, "ColorWarn", &color);
+					g_free(PREFS->color_warn);
+					PREFS->color_warn = g_strdup_printf("#%06x", color);
+				}
+				else
+				{
+					homebank_pref_get_boolean(keyfile, group, "CustomColors", &PREFS->custom_colors);
+					
+					homebank_pref_get_string(keyfile, group, "ColorExp" , &PREFS->color_exp);
+					homebank_pref_get_string(keyfile, group, "ColorInc" , &PREFS->color_inc);
+					homebank_pref_get_string(keyfile, group, "ColorWarn", &PREFS->color_warn);
+
+					homebank_pref_get_boolean(keyfile, group, "RulesHint", &PREFS->rules_hint);
+				}
+
+				DB( g_print(" color exp: %s\n", PREFS->color_exp) );
+				DB( g_print(" color inc: %s\n", PREFS->color_inc) );
+				DB( g_print(" color wrn: %s\n", PREFS->color_warn) );
+
+
 				homebank_pref_get_string(keyfile, group, "WalletPath", &PREFS->path_wallet);
 				homebank_pref_get_string(keyfile, group, "ImportPath", &PREFS->path_import);
 				homebank_pref_get_string(keyfile, group, "ExportPath", &PREFS->path_export);
-				//homebank_pref_get_string(keyfile, group, "NavigatorPath", &PREFS->path_navigator);
 
 				homebank_pref_get_boolean(keyfile, group, "LoadLast", &PREFS->loadlast);
+				homebank_pref_get_boolean(keyfile, group, "ShowSplash", &PREFS->showsplash);
 				homebank_pref_get_boolean(keyfile, group, "HeritDate", &PREFS->heritdate);
 				
 				if( g_key_file_has_key(keyfile, group, "ColumnsOpe", NULL) )
 				{
-				gint *pos;
+				gboolean *bsrc;
+				gint *src, i;
 				gsize length;
 
-					pos = g_key_file_get_boolean_list(keyfile, group, "ColumnsOpe",
-						&length, &error);
+					if(!strcmp("0.2", version))	//retrieve old 0.1 or 0.2 visibility boolean
+					{
+						bsrc = g_key_file_get_boolean_list(keyfile, group, "ColumnsOpe", &length, &error);
+						if( length == NUM_LST_DSPOPE-1 )
+						{
+							//and convert
+							for(i=0; i<NUM_LST_DSPOPE-1 ; i++)
+							{
+								PREFS->lst_ope_columns[i] = (bsrc[i] == TRUE) ? i+1 : -(i+1);
+							}
+						}
+						g_free(bsrc);
+					}
+					else
+					{
+						src = g_key_file_get_integer_list(keyfile, group, "ColumnsOpe", &length, &error);
+						if( length == NUM_LST_DSPOPE-1 )
+							memcpy(PREFS->lst_ope_columns, src, length*sizeof(gint));
+						g_free(src);
+					}
 
-					if( length == NUM_COL_OPE)
-						memcpy(PREFS->lst_ope_columns, pos, length*sizeof(gboolean));
-
-					g_free(pos);
 				}
+				
+				homebank_pref_get_integer(keyfile, group, "OpeSortId", &PREFS->lst_ope_sort_id);
+				homebank_pref_get_integer(keyfile, group, "OpeSortOrder", &PREFS->lst_ope_sort_order);
+
+			    DB( g_print("set sort to %d %d\n", PREFS->lst_ope_sort_id, PREFS->lst_ope_sort_order) );
+
 
 			group = "Windows";
 
@@ -497,6 +581,12 @@ GError *error = NULL;
 				homebank_pref_get_wingeometry(keyfile, group, "Bud", &PREFS->bud_wg);
 				homebank_pref_get_wingeometry(keyfile, group, "Car", &PREFS->car_wg);
 
+				homebank_pref_get_integer(keyfile, group, "WalVPaned", &PREFS->wal_vpaned);
+				homebank_pref_get_boolean(keyfile, group, "WalToolbar", &PREFS->wal_toolbar);
+				homebank_pref_get_boolean(keyfile, group, "WalStatusbar", &PREFS->wal_statusbar);
+				homebank_pref_get_boolean(keyfile, group, "WalUpcoming", &PREFS->wal_upcoming);
+
+
 			group = "Format";
 
 				homebank_pref_get_string(keyfile, group, "DateFmt", &PREFS->date_format);
@@ -552,7 +642,6 @@ GError *error = NULL;
 
 			//PREFS->euro_symbol = g_locale_to_utf8(tmpstr, -1, NULL, NULL, NULL);
 
-		//report options
 			group = "Report";
 
 				homebank_pref_get_boolean(keyfile, group, "StatByAmount", &PREFS->stat_byamount);
@@ -579,11 +668,6 @@ GError *error = NULL;
 		g_key_file_free (keyfile);
 	}
 
-	/* update to tango ;-) */
-	homebank_pref_update_to_tango_colors();
-
-	//homebank_pref_createformat();
-
 	return retval;
 }
 
@@ -629,13 +713,13 @@ gsize length;
 		g_key_file_set_integer (keyfile, group, "BarStyle", PREFS->toolbar_style);
 		//g_key_file_set_integer (keyfile, group, "BarImageSize", PREFS->image_size);
 
-		g_key_file_set_integer (keyfile, group, "ColorExp" , PREFS->color_exp);
-		g_key_file_set_integer (keyfile, group, "ColorInc" , PREFS->color_inc);
-		g_key_file_set_integer (keyfile, group, "ColorWarn", PREFS->color_warn);
+		g_key_file_set_boolean (keyfile, group, "CustomColors", PREFS->custom_colors);
+		g_key_file_set_string (keyfile, group, "ColorExp" , PREFS->color_exp);
+		g_key_file_set_string (keyfile, group, "ColorInc" , PREFS->color_inc);
+		g_key_file_set_string (keyfile, group, "ColorWarn", PREFS->color_warn);
+
+		g_key_file_set_boolean (keyfile, group, "RulesHint", PREFS->rules_hint);
 
-		#if DOWIZARD == 1
-		g_key_file_set_boolean (keyfile, group, "RunWizard", PREFS->runwizard);
-		#endif
 
 		homebank_pref_set_string  (keyfile, group, "WalletPath"   , PREFS->path_wallet);
 		homebank_pref_set_string  (keyfile, group, "ImportPath"   , PREFS->path_import);
@@ -643,8 +727,12 @@ gsize length;
 		//g_key_file_set_string  (keyfile, group, "NavigatorPath", PREFS->path_navigator);
 
 		g_key_file_set_boolean (keyfile, group, "LoadLast", PREFS->loadlast);
+		g_key_file_set_boolean (keyfile, group, "ShowSplash", PREFS->showsplash);
 		g_key_file_set_boolean (keyfile, group, "HeritDate", PREFS->heritdate);
-		g_key_file_set_boolean_list(keyfile, group, "ColumnsOpe", PREFS->lst_ope_columns, NUM_COL_OPE);
+
+		g_key_file_set_integer_list(keyfile, group, "ColumnsOpe", PREFS->lst_ope_columns, NUM_LST_DSPOPE-1);
+		g_key_file_set_integer     (keyfile, group, "OpeSortId" , PREFS->lst_ope_sort_id);
+		g_key_file_set_integer     (keyfile, group, "OpeSortOrder" , PREFS->lst_ope_sort_order);
 
 		// added v3.4
 		DB( g_print(" -> ** windows\n") );
@@ -657,6 +745,12 @@ gsize length;
 		g_key_file_set_integer_list(keyfile, group, "Bud", (gint *)&PREFS->bud_wg, 4);
 		g_key_file_set_integer_list(keyfile, group, "Car", (gint *)&PREFS->car_wg, 4);
 
+		g_key_file_set_integer (keyfile, group, "WalVPaned" , PREFS->wal_vpaned);
+		g_key_file_set_boolean (keyfile, group, "WalToolbar", PREFS->wal_toolbar);
+		g_key_file_set_boolean (keyfile, group, "WalStatusbar", PREFS->wal_statusbar);
+		g_key_file_set_boolean (keyfile, group, "WalUpcoming", PREFS->wal_upcoming);
+
+
 		DB( g_print(" -> ** format\n") );
 
 		group = "Format";
