@@ -104,7 +104,7 @@ enum
 
 gchar *CYA_BUDGSELECT[] = { N_("Category"), N_("Subcategory"), NULL };
 
-gchar *CYA_KIND[] = { N_("Expense"), N_("Income"), NULL };
+gchar *CYA_KIND[] = { N_("Exp. & Inc."), N_("Expense"), N_("Income"), NULL };
 
 gchar *CYA_BUDGETSELECT[] = { N_("Spent & Budget"), N_("Spent"), N_("Budget"), N_("Decay"), NULL };
 
@@ -113,13 +113,13 @@ extern gchar *CYA_RANGE[];
 extern gchar *CYA_SELECT[];
 
 static GtkActionEntry entries[] = {
-  { "List"    , "hb-stock-view-list" , N_("List")  , NULL,    N_("View results as list"), G_CALLBACK (repbudget_action_viewlist) },
-  { "Bar"     , "hb-stock-view-bar"  , N_("Bar")   , NULL,    N_("View results as bars"), G_CALLBACK (repbudget_action_viewbar) },
+  { "List"    , "hb-view-list" , N_("List")  , NULL,    N_("View results as list"), G_CALLBACK (repbudget_action_viewlist) },
+  { "Bar"     , "hb-view-bar"  , N_("Bar")   , NULL,    N_("View results as bars"), G_CALLBACK (repbudget_action_viewbar) },
 
-  { "Detail"  , "hb-stock-ope-show"  , N_("Detail"), NULL,    N_("Toggle detail"), G_CALLBACK (repbudget_action_detail) },
-  { "Legend"  , "hb-stock-legend"    , N_("Legend"), NULL,    N_("Toggle legend"), G_CALLBACK (repbudget_action_legend) },
+  { "Detail"  , "hb-ope-show"  , N_("Detail"), NULL,    N_("Toggle detail"), G_CALLBACK (repbudget_action_detail) },
+  { "Legend"  , "hb-legend"    , N_("Legend"), NULL,    N_("Toggle legend"), G_CALLBACK (repbudget_action_legend) },
 
-  { "Refresh" , "hb-stock-refresh"   , N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (repbudget_action_refresh) },
+  { "Refresh" , GTK_STOCK_REFRESH, N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (repbudget_action_refresh) },
 };
 
 static guint n_entries = G_N_ELEMENTS (entries);
@@ -256,12 +256,9 @@ gdouble decay;
 
 	//original formula
 	//decay = ABS(budget) - ABS(spent);
-	
-	decay = budget - spent;
-	//then the decay sign is determined by budget sign
-	if( budget < 0 )
-		decay *= -1;
 
+	decay = spent - budget;
+	 
 	return decay;
 }
 
@@ -427,7 +424,6 @@ struct repbudget_data *data;
 		gtk_widget_hide(data->GR_detail);
 }
 
-
 static void repbudget_detail(GtkWidget *widget, gpointer user_data)
 {
 struct repbudget_data *data;
@@ -455,10 +451,17 @@ GtkTreeIter  iter;
 		list = g_list_first(GLOBALS->ope_list);
 		while (list != NULL)
 		{
+		Account *acc;
 		Operation *ope = list->data;
 
 			//DB( g_print(" get %s\n", ope->ope_Word) );
 
+			acc = da_acc_get(ope->account);
+			if(acc != NULL)
+			{
+				if((acc->flags & AF_CLOSED)) goto next1;
+				if(!(acc->flags & AF_BUDGET)) goto next1;
+			}
 
 			//filter here
 			if( !(ope->flags & OF_REMIND) && (ope->date >= data->mindate) && (ope->date <= data->maxdate))
@@ -490,6 +493,7 @@ GtkTreeIter  iter;
 				}
 
 			}
+next1:
 			list = g_list_next(list);
 		}
 
@@ -719,10 +723,6 @@ next1:
 			if( entry == NULL)
 				continue;
 
-			// display expense or income
-			if( tmpkind !=  ((entry->flags & GF_INCOME) ? 1 : 0)) continue;
-
-
 			if(entry->flags & GF_SUB)
 			{
 			Category *parent = da_cat_get( entry->parent);
@@ -756,6 +756,13 @@ next1:
 						break;
 				}
 
+				// display expense or income (filter on amount and not category hupothetical flag
+				//if( tmpkind !=  (entry->flags & GF_INCOME)) continue;
+				if( tmpkind == 1 && tmp_budget[pos] > 0)
+					continue;
+				
+				if( tmpkind == 2 && tmp_budget[pos] < 0)
+					continue;
 
 
 				if(tmp_budget[pos] || tmp_spent[pos])
@@ -819,29 +826,6 @@ next1:
 	g_free(tmp_budget);
 	g_free(tmp_hasbudget);
 
-  /* update info range text */
-/*
-	{
-	gchar buffer1[128];
-	gchar buffer2[128];
-	GDate *date;
-	gchar *info;
-
-		date = g_date_new_julian(data->mindate);
-		g_date_strftime (buffer1, 128-1, "%x", date);
-		g_date_set_julian(date, data->maxdate);
-		g_date_strftime (buffer2, 128-1, "%x", date);
-		g_date_free(date);
-
-		info = g_strdup_printf("%s -> %s", buffer1, buffer2);
-
-		gtk_label_set_text(GTK_LABEL(data->TX_info), info);
-
-
-		g_free(info);
-	}
-*/
-
 
 }
 
@@ -1014,7 +998,8 @@ GError *error = NULL;
 	gtk_window_set_title (GTK_WINDOW (window), _("Budget report"));
 
 	//set the window icon
-	homebank_window_set_icon_from_file(GTK_WINDOW (window), "report_budget.svg");
+	//homebank_window_set_icon_from_file(GTK_WINDOW (window), "report_budget.svg");
+	gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_REP_BUDGET);
 
 
 	//window contents
@@ -1339,41 +1324,34 @@ static void budget_amount_cell_data_function (GtkTreeViewColumn *col,
                            GtkTreeIter       *iter,
                            gpointer           user_data)
    {
-GtkWidget *widget;
 gdouble  value;
-gchar   buf[128];
-gboolean minor;
-gchar *markuptxt;
-guint32 color;
-
-	//get datas
-	gtk_tree_model_get(model, iter, GPOINTER_TO_INT(user_data), &value, -1);
+gchar *color;
+gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
+gint column_id = GPOINTER_TO_INT(user_data);
+	   
+	gtk_tree_model_get(model, iter, column_id, &value, -1);
 
 	if( value )
 	{
-		widget = g_object_get_data(G_OBJECT(model), "minor");
-		if(GTK_IS_TOGGLE_BUTTON(widget))
-		{
-			minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
-		}
+		mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->minor);
+
+		if( column_id == LST_BUDGET_DECAY)
+			color = get_minimum_color_amount (value, 0.0);
 		else
-			minor = 0;
-
-		mystrfmon(buf, 127, value, minor);
-
-		color = (value > 0) ? PREFS->color_inc : PREFS->color_exp;
-		markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", color, buf);
-		g_object_set(renderer, "markup", markuptxt, NULL);
-		g_free(markuptxt);
+			color = get_normal_color_amount(value);
 
+		g_object_set(renderer, 
+			"foreground",  color,
+			"text", buf,
+			NULL);
 	}
 	else
 	{
 		g_object_set(renderer, "text", "", NULL);
 	}
-
 }
 
+
 static GtkTreeViewColumn *amount_list_budget_column(gchar *name, gint id)
 {
 GtkTreeViewColumn  *column;
@@ -1415,7 +1393,7 @@ GtkTreeViewColumn  *column;
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), PREFS->rules_hint);
 
 	/* column: Name */
 	column = gtk_tree_view_column_new();
