@@ -90,10 +90,10 @@ static void repover_action_refresh(GtkAction *action, gpointer user_data);
 //next
 
 static GtkActionEntry entries[] = {
-  { "List"    , "hb-stock-view-list" , N_("List")   , NULL,   N_("View results as list"), G_CALLBACK (repover_action_viewlist) },
-  { "Line"    , "hb-stock-view-line" , N_("Line")   , NULL,   N_("View results as lines"), G_CALLBACK (repover_action_viewline) },
+  { "List"    , "hb-view-list" , N_("List")   , NULL,   N_("View results as list"), G_CALLBACK (repover_action_viewlist) },
+  { "Line"    , "hb-view-line" , N_("Line")   , NULL,   N_("View results as lines"), G_CALLBACK (repover_action_viewline) },
 
-  { "Refresh" , "hb-stock-refresh"   , N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (repover_action_refresh) },
+  { "Refresh" , GTK_STOCK_REFRESH   , N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (repover_action_refresh) },
 };
 
 static guint n_entries = G_N_ELEMENTS (entries);
@@ -626,10 +626,8 @@ GError *error = NULL;
 	gtk_window_set_title (GTK_WINDOW (window), _("Overdrawn report"));
 
 	//set the window icon
-	homebank_window_set_icon_from_file(GTK_WINDOW (window), "report_overdrawn.svg");
-
-
-
+	//homebank_window_set_icon_from_file(GTK_WINDOW (window), "report_overdrawn.svg");
+	gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_REP_OVER);
 
 	//window contents
 	mainvbox = gtk_vbox_new (FALSE, 0);
@@ -865,44 +863,61 @@ GError *error = NULL;
 static void repover_date_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 gchar *datestr;
-gchar *markuptxt;
 gboolean is_over;
+gchar *color;
+gint weight;
 
 	gtk_tree_model_get(model, iter,
 		LST_OVER_DATESTR, &datestr,
 		LST_OVER_OVER, &is_over,
 		-1);
 
+	color = NULL;
+	weight = PANGO_WEIGHT_NORMAL;
+
 	if(is_over==TRUE)
 	{
-		markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", PREFS->color_warn, datestr);
-		g_object_set(renderer, "markup", markuptxt, NULL);
-		g_free(markuptxt);
+		if(PREFS->custom_colors == TRUE)
+			color = PREFS->color_warn;
+		
+		weight = PANGO_WEIGHT_BOLD;
 	}
-	else
-	g_object_set(renderer, "text", datestr, NULL);
-
+	
+	g_object_set(renderer, 
+		"weight", weight,
+		"foreground",  color,
+		"text", datestr,
+		NULL);
 }
 
 static void repover_text_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 gchar *buf;
-gchar *markuptxt;
 gboolean is_over;
+gchar *color;
+gint weight;
 
 	gtk_tree_model_get(model, iter,
 		LST_OVER_WORDING, &buf,
 		LST_OVER_OVER, &is_over,
 		-1);
 
+	color = NULL;
+	weight = PANGO_WEIGHT_NORMAL;
+
 	if(is_over==TRUE)
 	{
-		markuptxt = g_markup_printf_escaped("<span color='#%06x'>%s</span>", PREFS->color_warn, buf);
-		g_object_set(renderer, "markup", markuptxt, NULL);
-		g_free(markuptxt);
+		if(PREFS->custom_colors == TRUE)
+			color = PREFS->color_warn;
+		
+		weight = PANGO_WEIGHT_BOLD;
 	}
-	else
-		g_object_set(renderer, "text", buf, NULL);
+	
+	g_object_set(renderer, 
+		"weight", weight,
+		"foreground",  color,
+		"text", buf,
+		NULL);
 
 }
 
@@ -912,49 +927,47 @@ static void repover_amount_cell_data_function (GtkTreeViewColumn *col,
                            GtkTreeIter       *iter,
                            gpointer           user_data)
 {
-GtkWidget *widget;
 gdouble  value;
-gchar   buf[128];
-gboolean minor;
-gchar *markuptxt;
-guint32 color;
+gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 gboolean is_over;
-
+gchar *color;
+gint weight;
 	//get datas
 	gtk_tree_model_get(model, iter,
 		LST_OVER_OVER, &is_over,
 		GPOINTER_TO_INT(user_data), &value,
 		-1);
 
-	if( value )
-	{
+	//fix: 400483
+	//value = arrondi(value, PREFS->base_cur.frac_digits);
 
-		widget = g_object_get_data(G_OBJECT(model), "minor");
-		if(GTK_IS_TOGGLE_BUTTON(widget))
-		{
-			minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
-		}
-		else
-			minor = 0;
-
-		mystrfmon(buf, 127, value, minor);
-
-		color = (value > 0) ? PREFS->color_inc : PREFS->color_exp;
-		if(is_over==TRUE) color = PREFS->color_warn;
-
-		markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", color, buf);
-
-		//debug
-		/*gboolean toto = g_utf8_validate(buf, -1, NULL);
-		gboolean toto2 = g_utf8_validate(markuptxt, -1, NULL);
-		g_print("DEBUG: '%s' (isutf8=%d) :: '%s' (isutf8=%d)\n", buf, toto, markuptxt, toto2);
-		*/
-		g_object_set(renderer, "markup", markuptxt, NULL);
-		g_free(markuptxt);
-	}
+	if( value == 0.0 )
+		g_object_set(renderer, "text", NULL, NULL);
 	else
 	{
-		g_object_set(renderer, "text", "", NULL);
+
+		mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->minor);
+
+		color = NULL;
+		weight = PANGO_WEIGHT_NORMAL;
+
+
+		if(value != 0.0 && PREFS->custom_colors == TRUE)
+			color = (value > 0.0) ? PREFS->color_inc : PREFS->color_exp;
+
+		if(is_over==TRUE)
+		{
+			if(PREFS->custom_colors == TRUE)
+				color = PREFS->color_warn;
+		
+			weight = PANGO_WEIGHT_BOLD;
+		}
+
+		g_object_set(renderer, 
+			"weight", weight,
+			"foreground",  color,
+			"text", buf,
+			NULL);
 	}
 
 }
@@ -1002,7 +1015,7 @@ GtkTreeViewColumn  *column;
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), PREFS->rules_hint);
 
 	/* column debug over */
 /*
