@@ -118,21 +118,24 @@ static void statistic_action_legend(GtkAction *action, gpointer user_data);
 static void statistic_action_rate(GtkAction *action, gpointer user_data);
 static void statistic_action_filter(GtkAction *action, gpointer user_data);
 static void statistic_action_refresh(GtkAction *action, gpointer user_data);
+static void statistic_action_export(GtkAction *action, gpointer user_data);
 
 static void statistic_busy(GtkWidget *widget, gboolean state);
 
 
 static GtkActionEntry entries[] = {
-  { "List"    , "hb-stock-view-list" , N_("List")   , NULL,    N_("View results as list"), G_CALLBACK (statistic_action_viewlist) },
-  { "Bar"     , "hb-stock-view-bar"  , N_("Bar")    , NULL,    N_("View results as bars"), G_CALLBACK (statistic_action_viewbar) },
-  { "Pie"     , "hb-stock-view-pie"  , N_("Pie")    , NULL,    N_("View results as pies"), G_CALLBACK (statistic_action_viewpie) },
+  { "List"    , "hb-view-list" , N_("List")   , NULL,    N_("View results as list"), G_CALLBACK (statistic_action_viewlist) },
+  { "Bar"     , "hb-view-bar"  , N_("Bar")    , NULL,    N_("View results as bars"), G_CALLBACK (statistic_action_viewbar) },
+  { "Pie"     , "hb-view-pie"  , N_("Pie")    , NULL,    N_("View results as pies"), G_CALLBACK (statistic_action_viewpie) },
 
-  { "Detail"  , "hb-stock-ope-show"  , N_("Detail") , NULL,    N_("Toggle detail"), G_CALLBACK (statistic_action_detail) },
-  { "Legend"  , "hb-stock-legend"    , N_("Legend") , NULL,    N_("Toggle legend"), G_CALLBACK (statistic_action_legend) },
-  { "Rate"    , "hb-stock-rate"      , N_("Rate")   , NULL,    N_("Toggle rate")  , G_CALLBACK (statistic_action_rate) },
+  { "Detail"  , "hb-ope-show"  , N_("Detail") , NULL,    N_("Toggle detail"), G_CALLBACK (statistic_action_detail) },
+  { "Legend"  , "hb-legend"    , N_("Legend") , NULL,    N_("Toggle legend"), G_CALLBACK (statistic_action_legend) },
+  { "Rate"    , "hb-rate"      , N_("Rate")   , NULL,    N_("Toggle rate")  , G_CALLBACK (statistic_action_rate) },
 
-  { "Filter"  , "hb-stock-filter"    , N_("Filter") , NULL,   N_("Edit the filter"), G_CALLBACK (statistic_action_filter) },
-  { "Refresh" , "hb-stock-refresh"   , N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (statistic_action_refresh) },
+  { "Filter"  , "hb-filter"    , N_("Filter") , NULL,   N_("Edit the filter"), G_CALLBACK (statistic_action_filter) },
+  { "Refresh" , GTK_STOCK_REFRESH   , N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (statistic_action_refresh) },
+
+  { "Export" , "hb-file-export", N_("Export")  , NULL,   N_("Export as CSV"), G_CALLBACK (statistic_action_export) },
 };
 
 static guint n_entries = G_N_ELEMENTS (entries);
@@ -150,6 +153,8 @@ static const gchar *ui_info =
 "      <separator/>"
 "    <toolitem action='Filter'/>"
 "    <toolitem action='Refresh'/>"
+"      <separator/>"
+"    <toolitem action='Export'/>"
 "  </toolbar>"
 "</ui>";
 
@@ -175,6 +180,7 @@ static void statistic_range_change(GtkWidget *widget, gpointer user_data);
 static void statistic_detail(GtkWidget *widget, gpointer user_data);
 static void statistic_update(GtkWidget *widget, gpointer user_data);
 static void statistic_update_total(GtkWidget *widget, gpointer user_data);
+static void statistic_export_csv(GtkWidget *widget, gpointer user_data);
 static void statistic_compute(GtkWidget *widget, gpointer user_data);
 static void statistic_sensitive(GtkWidget *widget, gpointer user_data);
 static void statistic_toggle_detail(GtkWidget *widget, gpointer user_data);
@@ -319,7 +325,7 @@ struct statistic_data *data = user_data;
 	//debug
 	//create_deffilter_window(data->filter, TRUE);
 
-	if(create_deffilter_window(data->filter, TRUE) == GTK_RESPONSE_ACCEPT)
+	if(create_deffilter_window(data->filter, TRUE) != GTK_RESPONSE_REJECT)
 		statistic_compute(data->window, NULL);
 }
 
@@ -330,6 +336,13 @@ struct statistic_data *data = user_data;
 	statistic_compute(data->window, NULL);
 }
 
+static void statistic_action_export(GtkAction *action, gpointer user_data)
+{
+struct statistic_data *data = user_data;
+
+	statistic_export_csv(data->window, NULL);
+}
+
 
 
 /* ======================== */
@@ -742,6 +755,73 @@ gboolean minor;
 
 }
 
+static void statistic_export_csv(GtkWidget *widget, gpointer user_data)
+{
+struct statistic_data *data;
+GtkTreeModel *model;
+GtkTreeIter	iter;
+gboolean valid;
+gchar *filename = NULL;
+GIOChannel *io;
+gchar *outstr, *name;
+gint tmpfor;
+
+	DB( g_print("(statistic) export csv\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	tmpfor  = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_for));
+
+	name = g_strdup_printf("hb_stat_%s.csv", CYA_STATSELECT[tmpfor]);
+
+	if( homebank_csv_file_chooser(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_SAVE, &filename, name) == TRUE )
+	{
+		DB( g_print(" + filename is %s\n", filename) );
+
+		io = g_io_channel_new_file(filename, "w", NULL);
+		if(io != NULL)
+		{
+			// header
+			outstr = g_strdup_printf("%s;%s;%s;%s\n", _("Result"), _("expense"), _("Income"), _("Balance"));
+			g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
+			
+			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report));
+			valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+			while (valid)
+			{
+			gchar *name;
+			gdouble exp, inc, bal;
+
+				gtk_tree_model_get (model, &iter,
+					//LST_STAT_KEY, i,
+					LST_STAT_NAME   , &name,
+					LST_STAT_EXPENSE, &exp,
+					LST_STAT_INCOME , &inc,
+					LST_STAT_BALANCE, &bal,
+					-1);
+
+				outstr = g_strdup_printf("%s;%.2f;%.2f;%.2f\n", name, exp, inc, bal);
+				g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
+
+				DB( g_print("%s", outstr) );
+
+				g_free(outstr);
+
+				valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+			}
+			
+			g_io_channel_unref (io);
+		}
+
+		g_free( filename );
+	}
+
+	g_free(name);
+
+
+}
+
+
 static void statistic_compute(GtkWidget *widget, gpointer user_data)
 {
 struct statistic_data *data;
@@ -1051,28 +1131,7 @@ gdouble exprate, incrate, balrate;
 	g_free(tmp_expense);
 	g_free(tmp_income);
 
-  /* update info range text */
-/*
-	{
-	gchar buffer1[128];
-	gchar buffer2[128];
-	GDate *date;
-	gchar *info;
 
-		date = g_date_new_julian(data->filter->mindate);
-		g_date_strftime (buffer1, 128-1, "%x", date);
-		g_date_set_julian(date, data->filter->maxdate);
-		g_date_strftime (buffer2, 128-1, "%x", date);
-		g_date_free(date);
-
-		info = g_strdup_printf("%s -> %s", buffer1, buffer2);
-
-		gtk_label_set_text(GTK_LABEL(data->TX_info), info);
-
-
-		g_free(info);
-	}
-*/
 	statistic_update_total(widget,NULL);
 
 	statistic_update(widget, user_data);
@@ -1091,7 +1150,7 @@ static void statistic_sensitive(GtkWidget *widget, gpointer user_data)
 struct statistic_data *data;
 gboolean active;
 gboolean sensitive;
-gint page, view;
+gint page;
 
 	DB( g_print("(statistic) sensitive\n") );
 
@@ -1105,13 +1164,18 @@ gint page, view;
 //	gtk_widget_set_sensitive(data->TB_buttons[ACTION_REPBUDGET_DETAIL], sensitive);
 	gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/ToolBar/Detail"), sensitive);
 
-	view = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_view));
+	//view = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_view));
 
+
+	
 	sensitive = page == 0 ? FALSE : TRUE;
 	//gtk_widget_set_sensitive(data->CY_view, sensitive);
 //	gtk_widget_set_sensitive(data->TB_buttons[ACTION_REPBUDGET_LEGEND], sensitive);
 	gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/ToolBar/Legend"), sensitive);
 
+	sensitive = page == 0 ? TRUE : FALSE;
+	gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/ToolBar/Rate"), sensitive);
+
 
 }
 
@@ -1291,7 +1355,7 @@ static void statistic_setup(struct statistic_data *data)
 	
 	/* 3.4 : make int transfer out of stats */
 	data->filter->option[FILTER_PAYMODE] = 1;
-	data->filter->paymode[PAYMODE_PERSTRANSFER] = FALSE;
+	data->filter->paymode[PAYMODE_INTXFER] = FALSE;
 
 	/* if ope get date bounds */
 	if(g_list_length(GLOBALS->ope_list) > 0)
@@ -1420,7 +1484,8 @@ GError *error = NULL;
 	gtk_window_set_title (GTK_WINDOW (window), _("Statistics Report"));
 
 	//set the window icon
-	homebank_window_set_icon_from_file(GTK_WINDOW (window), "report_stats.svg");
+	//homebank_window_set_icon_from_file(GTK_WINDOW (window), "report_stats.svg");
+	gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_REP_STATS);
 
 
 	//window contents
@@ -1767,39 +1832,26 @@ static void statistic_amount_cell_data_function (GtkTreeViewColumn *col,
                            GtkTreeIter       *iter,
                            gpointer           user_data)
 {
-GtkWidget *widget;
 gdouble  value;
-gchar   buf[128];
-gboolean minor;
-gchar *markuptxt;
-guint32 color;
+gchar *color;
+gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 
-	//get datas
 	gtk_tree_model_get(model, iter, GPOINTER_TO_INT(user_data), &value, -1);
 
 	if( value )
 	{
-		widget = g_object_get_data(G_OBJECT(model), "minor");
-		if(GTK_IS_TOGGLE_BUTTON(widget))
-		{
-			minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
-		}
-		else
-			minor = 0;
+		mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->minor);
+		
+		color = get_normal_color_amount(value);
 
-		mystrfmon(buf, 127, value, minor);
-
-		color = (value > 0) ? PREFS->color_inc : PREFS->color_exp;
-
-		markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", color, buf);
-		g_object_set(renderer, "markup", markuptxt, NULL);
-		g_free(markuptxt);
-	}
+		g_object_set(renderer, 
+			"foreground",  color,
+			"text", buf,
+			NULL);	}
 	else
 	{
 		g_object_set(renderer, "text", "", NULL);
 	}
-
 }
 
 
@@ -1867,7 +1919,7 @@ GtkTreeViewColumn  *column;
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), PREFS->rules_hint);
 
 	/* column: Name */
 	column = gtk_tree_view_column_new();
