@@ -20,9 +20,6 @@
 #ifndef __HOMEBANK_WIDGETS_H__
 #define __HOMEBANK_WIDGETS_H__
 
-void load_paymode_icons(void);
-void free_paymode_icons(void);
-
 GtkWidget *make_label(char *str, gfloat xalign, gfloat yalign);
 GtkWidget *make_text(gfloat xalign);
 GtkWidget *make_string(GtkWidget *label);
@@ -52,6 +49,12 @@ GtkWidget *make_poparchive(GtkWidget *label);
 guint make_popcategory_populate(GtkComboBox *combobox, GList *srclist);
 GtkWidget *make_popcategory(GtkWidget *label);
 
+void load_paymode_icons(void);
+void free_paymode_icons(void);
+void load_nainex_icons(void);
+void free_nainex_icons(void);
+
 GtkWidget *make_paymode(GtkWidget *label);
+GtkWidget *make_nainex(GtkWidget *label);
 
 #endif /* __HOMEBANK_WIDGETS_H__ */
