@@ -116,8 +116,7 @@ gint i, j;
 					     if(!strcmp (attribute_names[i], "key"     )) { entry->key   = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "flags"   )) { entry->flags = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "pos"     )) { entry->pos   = atoi(attribute_values[i]); }
-					//todo: for stock account
-					//else if(!strcmp (attribute_names[i], "type"    )) { entry->type = atoi(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "type"    )) { entry->type = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "name"    )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->name = g_strdup(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "number"  )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->number = g_strdup(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "bankname")) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->bankname = g_strdup(attribute_values[i]); }
@@ -151,6 +150,29 @@ gint i, j;
 				//all attribute loaded: append
 				da_acc_insert(entry);
 			}
+			
+			//assign
+			if(!strcmp (element_name, "asg"))
+			{
+			Assign *entry = da_asg_malloc();
+
+				for (i = 0; attribute_names[i] != NULL; i++)
+				{
+					DB( g_print(" att=%s val=%s\n", attribute_names[i], attribute_values[i]) );
+
+					     if(!strcmp (attribute_names[i], "key"     )) { entry->key   = atoi(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "name"    )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->name = g_strdup(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "exact" )) { entry->exact = g_ascii_strtod(attribute_values[i], NULL); }
+					else if(!strcmp (attribute_names[i], "payee"      )) { entry->payee = atoi(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "category"   )) { entry->category = atoi(attribute_values[i]); }
+
+				}
+				
+				//all attribute loaded: append
+				da_asg_append(entry);
+
+			}
+			
 		}
 		break;
 
@@ -277,6 +299,12 @@ gint i, j;
 		}
 		break;
 
+		case 'r':
+		{
+		}
+		break;
+
+
 		case 'o':
 		{
 			if(!strcmp (element_name, "ope"))
@@ -479,7 +507,14 @@ gboolean rc;
 
 			}
 
+			//upgrade to prior v0.4 file
+			// we must sort the archive list
+			if( version < 0.4 )
+			{
+			   GLOBALS->arc_list = da_archive_sort(GLOBALS->arc_list);
+			}
 
+			// next ?
 
 		}
 	}
@@ -534,16 +569,13 @@ gchar *tmpstr;
 
 		item->flags &= (AF_BUDGET|AF_CLOSED);
 
-		//todo: for stock account
-		//tmpstr = g_markup_printf_escaped("<account key=\"%d\" flags=\"%d\" type=\"%d\" name=\"%s\"\n"
-		tmpstr = g_markup_printf_escaped("<account key=\"%d\" flags=\"%d\" pos=\"%d\" name=\"%s\""
+		tmpstr = g_markup_printf_escaped("<account key=\"%d\" flags=\"%d\" pos=\"%d\" type=\"%d\" name=\"%s\""
 			" number=\"%s\" bankname=\"%s\" initial=\"%s\" minimum=\"%s\""
 			" cheque1=\"%d\" cheque2=\"%d\"/>\n",
 			item->key,
 			item->flags,
 			item->pos,
-			//todo: for stock account
-			//item->type,
+			item->type,
 			item->name == NULL ? "" : item->name,
 			item->number == NULL ? "" : item->number,
 			item->bankname == NULL ? "" : item->bankname,
@@ -663,6 +695,36 @@ gchar *tmpstr;
 	g_list_free(list);
 }
 
+
+/*
+** XML assign save
+*/
+static void homebank_asg_save_xml(GIOChannel *io)
+{
+GList *list;
+gchar *tmpstr;
+
+	list = g_hash_table_get_values(GLOBALS->h_rul);
+	while (list != NULL)
+	{
+	Assign *item = list->data;
+
+		tmpstr = g_markup_printf_escaped("<asg key=\"%d\" name=\"%s\" exact=\"%d\" payee=\"%d\" category=\"%d\"/>\n",
+			item->key,
+			item->name,
+			item->exact,
+			item->payee,
+			item->category
+		);
+			
+		g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
+		g_free(tmpstr);
+
+		list = g_list_next(list);
+	}
+	g_list_free(list);
+}
+
 /*
 ** XML archive save
 */
@@ -782,6 +844,7 @@ gchar *outstr;
 		homebank_pay_save_xml(io);
 		homebank_cat_save_xml(io);
 		homebank_tag_save_xml(io);
+		homebank_asg_save_xml(io);
 		homebank_arc_save_xml(io);
 		homebank_ope_save_xml(io);
 
